@@ -69,13 +69,16 @@ public interface AutoCryptService {
 
     /**
      * Get AutoCrypt string for outgoing email
+     * 
      * @param userId
      * @param cid
+     * @param oxUserId
+     * @param oxCid
      * @param emailAddress, should be the from address
      * @return
      * @throws OXException
      */
-    public String getOutgoingHeaderString (int userId, int cid, String emailAddress) throws OXException;
+    public String getOutgoingHeaderString(int userId, int cid, int oxUserId, int oxCid, String emailAddress) throws OXException;
 
     /**
      * Import a key from a header string
