@@ -112,9 +112,9 @@ abstract class AbstractGuardCipherService implements GuardCipherService {
      * @see com.openexchange.guard.crypto.internal.GuardCryptoService#generateRandomPassword()
      */
     @Override
-    public String generateRandomPassword() throws OXException {
+    public String generateRandomPassword(int userId, int cid) throws OXException {
         GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-        int length = configService.getIntProperty(GuardProperty.newPassLength);
+        int length = configService.getIntProperty(GuardProperty.newPassLength, userId, cid);
 
         SecureRandom random = new SecureRandom();
         StringBuilder newPassword = new StringBuilder(length);
