@@ -68,7 +68,7 @@ public class GuardRSACipherServiceImpl extends AbstractGuardCipherService {
 
     /**
      * Initializes a new {@link GuardRSACipherServiceImpl}.
-     * 
+     *
      * @param cipherAlgorithm The cipher algorithm
      * @throws OXException If the specified cipher algorithm does not exist, or if the key length of the specified algorithm exceeds the maximum defined
      */
@@ -133,6 +133,7 @@ public class GuardRSACipherServiceImpl extends AbstractGuardCipherService {
             // Decrypt the text using the secretKey
             cipher.init(Cipher.DECRYPT_MODE, secretKey);
             dectyptedText = cipher.doFinal(text);
+            return new String(dectyptedText, "UTF-8");
 
         } catch (Exception ex) {
             //TODO throw exception
@@ -140,7 +141,6 @@ public class GuardRSACipherServiceImpl extends AbstractGuardCipherService {
             return null;
         }
 
-        return new String(dectyptedText);
     }
 
     @Override
