@@ -92,8 +92,6 @@ public class GuardCipherActivator extends HousekeepingActivator {
         registerService(GuardCipherFactoryService.class, new GuardCipherFactoryServiceImpl());
 
         //Validating OX Guard Key configuration
-        GuardConfigurationService configurationService = this.getService(GuardConfigurationService.class);
-        int aesKeyLength = configurationService.getIntProperty(GuardProperty.aesKeyLength);
 
         ConfigurationValidator validator = new ConfigurationValidator(this.getService(GuardConfigurationService.class));
         //Validate that the configured AES key length is a valid AES key length
