@@ -128,6 +128,9 @@ public class Guard extends AbstractRmiCLI<Void> {
             if (arg.trim().equals("-m") || arg.trim().equals("--import")) {
                 return Boolean.TRUE;
             }
+            if (arg.trim().equals("-M") || arg.trim().equals("--masterKey")) {
+                return Boolean.TRUE;
+            }
         }
         return Boolean.FALSE;
     }
@@ -168,6 +171,7 @@ public class Guard extends AbstractRmiCLI<Void> {
         options.addOption("o", "jmx-port", true, "JMX port (default: '9999')");
         options.addOption("x", "jmx-host", true, "JMX host (default: 'localhost')");
         options.addOption("r", "repair", true, "Check database integrity and repair if able.  Specify argument update or dryRun \ne.g. guard -r update");
+        options.addOption("M", "masterKey", false, "Create new master key");
     }
 
     /*
@@ -240,6 +244,8 @@ public class Guard extends AbstractRmiCLI<Void> {
             } else if (cmd.hasOption('m')) {
                 String file = cmd.getOptionValue('m');
                 importPublic(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), file);
+            } else if (cmd.hasOption('M')) {
+                createMasterKey(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword));
             } else if (cmd.hasOption('r')) {
                 String dry = cmd.getOptionValue('r');
                 if (dry != null && dry.toLowerCase().startsWith("update")) {
@@ -327,6 +333,12 @@ public class Guard extends AbstractRmiCLI<Void> {
         System.out.println("Done");
     }
 
+    private void createMasterKey(GuardMaintenanceMBean proxy) throws MBeanException {
+        int newIndex = proxy.createMaster();
+        System.out.print("New master keys created with index ");
+        System.out.println(newIndex);
+    }
+
     /*
      * (non-Javadoc)
      *
