@@ -65,8 +65,9 @@ public enum GuardAuthExceptionCodes implements DisplayableOXExceptionCode {
     LOCKOUT("Account lockout.", GuardAuthExceptionMessages.LOCKOUT_MSG, CATEGORY_PERMISSION_DENIED, 1),
     BAD_PASSWORD("Bad password.", GuardAuthExceptionMessages.BAD_PASSWORD_MSG, CATEGORY_PERMISSION_DENIED, 2),
     MISSING_SESSION("No valid session found.", GuardAuthExceptionMessages.MISSING_SESSION_MSG,CATEGORY_PERMISSION_DENIED,3),
-    FORBIDDEN("The operation is not permitted.", GuardAuthExceptionMessages.FORBIDDEN_MSG,CATEGORY_PERMISSION_DENIED,4);
-    ;
+    FORBIDDEN("The operation is not permitted.", GuardAuthExceptionMessages.FORBIDDEN_MSG,CATEGORY_PERMISSION_DENIED,4),
+    AUTH_MISSING("Authentication parameter missing.", GuardAuthExceptionMessages.AUTH_MISSING_MSG, CATEGORY_ERROR, 5),
+    TOKEN_ERROR("Unable to get session token.", GuardAuthExceptionMessages.TOKEN_ERROR_MSG, CATEGORY_ERROR, 6);
 
     private String message;
     private String displayMessage;
