@@ -64,41 +64,45 @@ import com.openexchange.exception.OXExceptionStrings;
  */
 public enum GuardCoreExceptionCodes implements DisplayableOXExceptionCode {
 
-    SQL_ERROR("An SQL error occurred: %1$s", CATEGORY_ERROR, 1),
+    SQL_ERROR("An SQL error occurred: %1$", GuardCoreExceptionMessages.SQL_ERROR_MSG, CATEGORY_ERROR, 1),
 
-    PARAMETER_MISSING("The parameter \"%1$s\" is missing.", Category.CATEGORY_ERROR, 2),
+    PARAMETER_MISSING("The parameter \"%1$s\" is missing.", GuardCoreExceptionMessages.PARAMETER_MISSING_MSG, Category.CATEGORY_ERROR, 2),
 
-    JSON_PARAMETER_MISSING("The parameter \"%1$s\" is missing in provided JSON.", Category.CATEGORY_ERROR, 3),
+    JSON_PARAMETER_MISSING("The parameter \"%1$s\" is missing in provided JSON.", GuardCoreExceptionMessages.JSON_PARAMETER_MISSING_MSG, Category.CATEGORY_ERROR, 3),
 
-    CONFIGURATION_ERROR("\"%1$s\" not configured correctly: \"%2$s\"", Category.CATEGORY_ERROR, 4),
+    CONFIGURATION_ERROR("\"%1$s\" not configured correctly: \"%2$s\"", GuardCoreExceptionMessages.CONFIGURATION_ERROR_MSG, Category.CATEGORY_ERROR, 4),
 
     /** An error occurred: %1$s */
-    UNEXPECTED_ERROR("An error occurred: %1$s", Category.CATEGORY_ERROR, 5),
+    UNEXPECTED_ERROR("An error occurred: %1$s", GuardCoreExceptionMessages.UNEXPECTED_ERROR_MSG, Category.CATEGORY_ERROR, 5),
 
     /** An I/O error occurred: %1$s */
-    IO_ERROR("An I/O error occurred: %1$s", Category.CATEGORY_ERROR, 6),
+    IO_ERROR("An I/O error occurred: %1$s", GuardCoreExceptionMessages.IO_ERROR_MSG, Category.CATEGORY_ERROR, 6),
 
-    KEY_NOT_FOUND_FOR_MAIL_ERROR("Could not find key for email \"%1$s\" in context %2$d", Category.CATEGORY_ERROR, 7),
+    KEY_NOT_FOUND_FOR_MAIL_ERROR("Could not find key for email \"%1$s\" in context %2$d", GuardCoreExceptionMessages.KEY_NOT_FOUND_FOR_MAIL_ERROR_MSG, Category.CATEGORY_ERROR, 7),
 
-    KEY_NOT_FOUND_FOR_IDS_ERROR("Could not find key for user with id \"%1$d\" in context %2$d", Category.CATEGORY_ERROR, 8),
+    KEY_NOT_FOUND_FOR_IDS_ERROR("Could not find key for user with id \"%1$d\" in context %2$d", GuardCoreExceptionMessages.KEY_NOT_FOUND_FOR_IDS_ERROR_MSG, Category.CATEGORY_ERROR, 8),
 
-    KEY_NOT_FOUND_FOR_KEY_ID_ERROR("Could not find key for key id \"%1$s\"", Category.CATEGORY_ERROR, 9),
+    KEY_NOT_FOUND_FOR_KEY_ID_ERROR("Could not find key for key id \"%1$s\"", GuardCoreExceptionMessages.KEY_NOT_FOUND_FOR_KEY_ID_ERROR_MSG, Category.CATEGORY_ERROR, 9),
 
-    JSON_ERROR("Error while processing provided JSON: %1$s.", Category.CATEGORY_ERROR, 10),
+    JSON_ERROR("Error while processing provided JSON: %1$s.", GuardCoreExceptionMessages.JSON_ERROR_MSG, Category.CATEGORY_ERROR, 10),
 
-    DISABLED_ERROR("Failed to %1$s because this is disabled per configuration.", CATEGORY_ERROR, 11),
+    DISABLED_ERROR("Failed to %1$s because this is disabled per configuration.", GuardCoreExceptionMessages.DISABLED_ERROR_MSG, CATEGORY_ERROR, 11),
 
-    KEY_NOT_FOUND("The requested key was not found", CATEGORY_ERROR, 12),
+    KEY_NOT_FOUND("The requested key was not found", GuardCoreExceptionMessages.KEY_NOT_FOUND_MSG, CATEGORY_ERROR, 12),
 
-    NOT_A_GUEST_ACCOUNT("The requested account is not a valid guest account", CATEGORY_ERROR, 13),
+    NOT_A_GUEST_ACCOUNT("The requested account is not a valid guest account", GuardCoreExceptionMessages.NOT_A_GUEST_ACCOUNT_MSG, CATEGORY_ERROR, 13),
 
-    PARAMETER_MISMATCH("The parameters \"%1$s\" and \"%2$s\" cannot be specified at the same time", CATEGORY_ERROR,14),
+    PARAMETER_MISMATCH("The parameters \"%1$s\" and \"%2$s\" cannot be specified at the same time", GuardCoreExceptionMessages.PARAMETER_MISMATCH_MSG, CATEGORY_ERROR,14),
 
-    INVALID_PARAMETER_VALUE("The parameter \"%1$s\" does not contain a valid value", CATEGORY_ERROR,15),
+    INVALID_PARAMETER_VALUE("The parameter \"%1$s\" does not contain a valid value", GuardCoreExceptionMessages.INVALID_PARAMETER_VALUE_MSG, CATEGORY_ERROR,15),
 
-    MULTIPART_UPLOAD_MISSING("Missing multipart/form-data", CATEGORY_ERROR, 16),
+    MULTIPART_UPLOAD_MISSING("Missing multipart/form-data", GuardCoreExceptionMessages.MULTIPART_UPLOAD_MISSING_MSG, CATEGORY_ERROR, 16),
 
-    MULTIPART_UPLOAD_ERROR("Error parsing multipart/form-data: %1$s", CATEGORY_ERROR, 17);
+    MULTIPART_UPLOAD_ERROR("Error parsing multipart/form-data: %1$s", GuardCoreExceptionMessages.MULTIPART_UPLOAD_ERROR_MSG, CATEGORY_ERROR, 17),
+
+    KEY_NOT_FOUND_PRIVATE_MASTER("Could not find the private master key of the specified key ring.", GuardCoreExceptionMessages.KEY_NOT_FOUND_PRIVATE_MASTER_MSG, CATEGORY_ERROR, 18),
+
+    KEY_NOT_FOUND_FOR_MAIL_ONLY_ERROR("Could not find key for email \"%1$s\"", GuardCoreExceptionMessages.KEY_NOT_FOUND_FOR_MAIL_ONLY_ERROR_MSG, Category.CATEGORY_ERROR, 19);
 
     ;
 
