@@ -275,6 +275,14 @@ public enum GuardProperty {
      * If no password is specified here, com.openexchange.guard.restApiPassword will be used as fallback (default)
      */
     basicAuthPassword(GuardProperty.EMPTY,GuardProperty.PREFIX + "mailResolverUrl."),
+    /**
+     * Index for master key encrypting database
+     */
+    masterKeyIndex(0),
+    /**
+     * Path to storage of oxguardpass files
+     */
+    masterKeyPath("/opt/open-xchange/guard"),
     /**
      * Max number of connections to same URL (route)
      */
