@@ -63,6 +63,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.configuration.osgi.Services;
+import com.openexchange.server.ServiceLookup;
 import com.openexchange.serverconfig.ServerConfigService;
 
 /**
@@ -74,7 +75,7 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
 
     private static final Logger logger = LoggerFactory.getLogger(GuardConfigurationServiceImpl.class);
 
-    private final ConfigurationService configurationService;
+    private final ServiceLookup services;
 
     /**
      * All reloadable properties
@@ -84,12 +85,21 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
     /**
      * Initialises a new {@link GuardConfigurationServiceImpl}.
      */
-    public GuardConfigurationServiceImpl(ConfigurationService configurationService) {
+    public GuardConfigurationServiceImpl(ServiceLookup services) {
         super();
-        this.configurationService = configurationService;
-        reloadConfiguration(configurationService);
+        this.services = services;
+        reloadConfiguration(getConfigService());
     }
 
+    /**
+     * Get configuration service
+     * getConfigService
+     *
+     * @return
+     */
+    private ConfigurationService getConfigService() {
+        return services.getService(ConfigurationService.class);
+    }
     /*
      * (non-Javadoc)
      *
@@ -122,7 +132,7 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
      */
     @Override
     public String getPropertyFromFile(String fileName, String property) {
-        Properties properties = configurationService.getFile(fileName);
+        Properties properties = getConfigService().getFile(fileName);
         return properties.getProperty(property);
     }
 
@@ -213,7 +223,7 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
      */
     @Override
     public File getPropertyFile(String propertyFileName) {
-        return configurationService.getFileByName(propertyFileName);
+        return getConfigService().getFileByName(propertyFileName);
     }
 
     /*
@@ -223,7 +233,7 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
      */
     @Override
     public File getPropertyDirectory(String propertyDirectory) {
-        return configurationService.getDirectory(propertyDirectory);
+        return getConfigService().getDirectory(propertyDirectory);
     }
 
     @Override
@@ -306,4 +316,5 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
     public Interests getInterests() {
         return DefaultInterests.builder().propertiesOfInterest("com.openexchange.guard.*").configFileNames("guard-core.properties", "server.properties").build();
     }
+
 }
