@@ -76,7 +76,8 @@ public class GuardConfigActivator extends HousekeepingActivator {
      */
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { ConfigViewFactory.class, ConfigurationService.class, ServerConfigService.class };
+        return new Class<?>[] { ConfigViewFactory.class, ConfigurationService.class,
+            ServerConfigService.class };
     }
 
     /*
@@ -91,7 +92,7 @@ public class GuardConfigActivator extends HousekeepingActivator {
 
         Services.setServiceLookup(this);
 
-        GuardConfigurationService guardConfigService = new GuardConfigurationServiceImpl(getService(ConfigurationService.class));
+        GuardConfigurationService guardConfigService = new GuardConfigurationServiceImpl(this);
         registerService(GuardConfigurationService.class, guardConfigService);
         registerSetting(new AdvancedUserSetting(guardConfigService));
         trackService(GuardConfigurationService.class);
