@@ -49,6 +49,7 @@
 
 package com.openexchange.guard.database;
 
+import java.util.List;
 import com.openexchange.exception.OXException;
 
 /**
@@ -108,4 +109,12 @@ public interface GuardShardingService {
      * @throws OXException
      */
     void updateAllShardSchemas() throws OXException;
+
+    /**
+     * Returns all guard shards that are registered within the configdb.
+     *
+     * @return {@link List} with the shard identifiers
+     * @throws OXException
+     */
+    List<Integer> getAllShards() throws OXException;
 }
