@@ -60,10 +60,13 @@ import org.xbill.DNS.TXTRecord;
 import org.xbill.DNS.TextParseException;
 import org.xbill.DNS.Type;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.dns.DNSResult;
 import com.openexchange.guard.dns.DNSService;
 import com.openexchange.guard.dns.ValidationResult;
 import com.openexchange.guard.dns.exception.DNSExceptionCodes;
+import com.openexchange.guard.dns.internal.FlagTrustingDNSValidator.ValidationMode;
 
 /**
  * {@link DNSServiceImpl}
@@ -76,22 +79,15 @@ public class DNSServiceImpl implements DNSService {
     private static final List<SRVRecord> EMPTY_LIST = Collections.emptyList();
     private static final ValidationResult VALIDATED = new ValidationResult(true);
     private static final ValidationResult NOT_VALIDATED = new ValidationResult(false);
-    private final DNSValidator validator;
-
-    /**
-     * Initializes a new {@link DNSServiceImpl}.
-     */
-    public DNSServiceImpl() {
-        this(null);
-    }
+    private final GuardConfigurationService guardConfigService;
 
     /**
      * Initializes a new {@link DNSServiceImpl}.
      *
      * @param validator A validator used for validating DNSSEC signatures of records, or null to not validate records
      */
-    public DNSServiceImpl(DNSValidator validator) {
-        this.validator = validator;
+    public DNSServiceImpl(GuardConfigurationService configService) {
+        this.guardConfigService = configService;
     }
 
     /**
@@ -102,7 +98,7 @@ public class DNSServiceImpl implements DNSService {
      * @throws TextParseException
      */
     @Override
-    public DNSResult getSrvs(String serviceName, String email) throws OXException {
+    public DNSResult getSrvs(String serviceName, String email, int userId, int cid) throws OXException {
         List<SRVRecord> list = new ArrayList<SRVRecord>();
         ValidatingResolverDecorator validatingResolver = null;
         if (!email.contains("@")) {
@@ -111,6 +107,9 @@ public class DNSServiceImpl implements DNSService {
         String domain = email.substring(email.indexOf("@") + 1);
         try {
             Lookup lookup = new Lookup(serviceName + domain, Type.ANY);
+            boolean allowUnsignedSRVRecords =
+                guardConfigService.getBooleanProperty(GuardProperty.allowUnsignedSRVRecords, userId, cid);
+            DNSValidator validator = new FlagTrustingDNSValidator(allowUnsignedSRVRecords ? ValidationMode.WARN : ValidationMode.FAIL);
             if (validator != null) {
                 //Setting up a DNS validator.
                 //The validating resolver  does _NOT_ get called if the DNS result is already in the local DNS cache.
