@@ -51,11 +51,8 @@ package com.openexchange.guard.dns.osgi;
 
 import org.slf4j.Logger;
 import com.openexchange.guard.configuration.GuardConfigurationService;
-import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.dns.DNSService;
 import com.openexchange.guard.dns.internal.DNSServiceImpl;
-import com.openexchange.guard.dns.internal.FlagTrustingDNSValidator;
-import com.openexchange.guard.dns.internal.FlagTrustingDNSValidator.ValidationMode;
 import com.openexchange.osgi.HousekeepingActivator;
 
 /**
@@ -82,8 +79,7 @@ public class DNSActivator extends HousekeepingActivator {
         Logger logger = org.slf4j.LoggerFactory.getLogger(DNSActivator.class);
         logger.info("Starting bundle: {}", context.getBundle().getSymbolicName());
         GuardConfigurationService guardConfigurationService = getService(GuardConfigurationService.class);
-        boolean allowUnsignedSRVRecords = guardConfigurationService.getBooleanProperty(GuardProperty.allowUnsignedSRVRecords);
-        registerService(DNSService.class, new DNSServiceImpl(new FlagTrustingDNSValidator(allowUnsignedSRVRecords ? ValidationMode.WARN : ValidationMode.FAIL)));
+        registerService(DNSService.class, new DNSServiceImpl(guardConfigurationService));
         logger.info("DNSService registered.");
     }
 
