@@ -387,7 +387,15 @@ public class GuardGuestServiceImpl implements GuardGuestService {
             this.fileCacheStorage.delete(itemId);
 
             //Remove from the storage
-            this.guestFileStorage.deleteEncrObj(fileCacheItem.getLocation());
+            try {
+                this.guestFileStorage.deleteEncrObj(fileCacheItem.getLocation());
+            } catch (OXException ex) {
+                if (ex.getCode() == 17) {
+                    LOGGER.info("File item already removed " + itemId);
+                } else {
+                    throw ex;
+                }
+            }
 
             //Delete meta data
             if(fileCacheItem.getLocation().contains(Storage.DELIMITER)) {
