@@ -102,7 +102,7 @@ public class BlobToMimeConverter implements GuestItemConverter {
     private final PGPMimeService          pgpMimeService;
     private final PGPKeyRetrievalStrategy keyRetrievalStrategy;
     private final HelpFileService         helpFileService;
-    private GuardConfigurationService     guardConfigurationService;
+    private final GuardConfigurationService     guardConfigurationService;
 
     /**
      * Initializes a new {@link BlobToMimeConverter}.
@@ -211,13 +211,13 @@ public class BlobToMimeConverter implements GuestItemConverter {
             int remoteHkpTimeout = guardConfigurationService.getIntProperty(GuardProperty.remoteKeyLookupTimeout);
             RecipKey recipKey = recipKeyLookupStrategy.lookup(guestIdentity.getIdentity(), remoteHkpTimeout);
             if (recipKey != null) {
-                return helpFileService.getHelpFiles(recipKey.getLocale());
+                return helpFileService.getHelpFiles(recipKey.getUserid(), recipKey.getCid(), recipKey.getLocale());
             } else {
                 return Collections.emptyList();
             }
 
         }
-        return helpFileService.getHelpFiles(guestIdentity.getOXUser().getLocale());
+        return helpFileService.getHelpFiles(guestIdentity.getOXUser().getId(), guestIdentity.getOXUser().getContextId(), guestIdentity.getOXUser().getLocale());
     }
 
     /**
