@@ -155,7 +155,7 @@ public class HKPIndex {
 
                     //Check and see if we can get public key from the backend if member; No guest and no HKP lookup;
                     RecipKeyService recipientKeyService = Services.getService(RecipKeyService.class);
-                    RecipKey key = recipientKeyService.getInternalRecipKey(assertUnwantedCharacters(search));
+                    RecipKey key = recipientKeyService.getInternalRecipKey(0, 0, assertUnwantedCharacters(search));
                     if (key != null) {
                         //This will create a key for a requested user if it is an OX user; but not a guest
                         if(key.isNewKey() && !key.isGuest()) {
