@@ -55,7 +55,8 @@ import com.openexchange.guard.hkp.servlets.HkpServlet;
 import com.openexchange.guard.keymanagement.services.AccountCreationService;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.RecipKeyService;
-import com.openexchange.guard.keys.PGPKeyService;
+import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
+import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.osgi.HousekeepingActivator;
 
@@ -74,8 +75,8 @@ public class HkpActivator extends HousekeepingActivator {
      */
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { HttpService.class, GuardConfigurationService.class, PGPKeyService.class, RecipKeyService.class,
-                                GuardKeyService.class, GuardRatifierService.class, AccountCreationService.class };
+        return new Class<?>[] { HttpService.class, GuardConfigurationService.class, RecipKeyService.class,
+                                GuardKeyService.class, GuardRatifierService.class, AccountCreationService.class, PGPKeysStorage.class, OGPGPKeysStorage.class };
     }
 
     /**
