@@ -49,7 +49,6 @@
 
 package com.openexchange.guard.hkpclient.osgi;
 
-import com.openexchange.config.Reloadable;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.dns.DNSService;
@@ -100,7 +99,6 @@ public class HkpClientActivator extends HousekeepingActivator {
         GuardConfigurationService guardConfigService = getService(GuardConfigurationService.class);
         boolean forceTLSForHKPSRV = guardConfigService.getBooleanProperty(GuardProperty.forceTLSForHKPSRV);
         RemoteHKPClientService remoteHKPClientService = new RemoteHKPClientService(this);
-        registerService(Reloadable.class, remoteHKPClientService);
         registerService(HKPClientService.class, new CachingHKPClientService(new SRVHKPClientService(remoteHKPClientService, forceTLSForHKPSRV, this)));
     }
 
