@@ -17,11 +17,13 @@ public interface HKPClientService {
      *
      * @param clientToken an identification token put into the X-UI-INTERNAL-ACCOUNT-ID header, or null not not set the header
      * @param email The email to get the public keys for
+     * @param id The ID of the key
+     * @param userId ID of the sender
      * @param timeout Procedure should timeout after specified milliseconds
      * @return A list of public keys found for the given email
      * @throws OXException
      */
-    public Collection<RemoteKeyResult> find(String clientToken, String email, int timeout) throws OXException;
+    public Collection<RemoteKeyResult> find(String clientToken, String email, int userId, int cid, int timeout) throws OXException;
 
     /**
      * Tries to find a specific key by email and ID
@@ -29,10 +31,12 @@ public interface HKPClientService {
      * @param clientToken an identification token put into the X-UI-INTERNAL-ACCOUNT-ID header, or null not not set the header
      * @param email The email to get the public keys for
      * @param id The ID of the key
+     * @param userId ID of the sender
+     * @param cid the Context of the sender
      * @param timeout Procedure should timeout after specified milliseconds
      * @return The public key for the given email and id
      * @throws OXException
      */
-    public RemoteKeyResult find(String clientToken, String email, Long id, int timeout) throws OXException;
+    public RemoteKeyResult find(String clientToken, String email, Long id, int userId, int cid, int timeout) throws OXException;
 
 }
