@@ -6,10 +6,6 @@ import java.util.Collection;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import com.openexchange.config.ConfigurationService;
-import com.openexchange.config.DefaultInterests;
-import com.openexchange.config.Interests;
-import com.openexchange.config.Reloadable;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.LongUtil;
 import com.openexchange.guard.configuration.GuardConfigurationService;
@@ -26,11 +22,9 @@ import com.openexchange.server.ServiceLookup;
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
  * @since v2.4.0
  */
-public class RemoteHKPClientService implements HKPClientService, Reloadable  {
+public class RemoteHKPClientService implements HKPClientService {
 
     private static final Logger logger = LoggerFactory.getLogger(RemoteHKPClientService.class);
-    private Collection<String> configuredRemoteHKPServers;
-    private Collection<String> untrustedRemoteHKPServers;
     private final HKPClientService delegate;
     private final GuardConfigurationService guardConfigService;
     private final ServiceLookup services;
@@ -43,19 +37,17 @@ public class RemoteHKPClientService implements HKPClientService, Reloadable  {
         this.delegate = delegate;
         this.guardConfigService = Services.getService(GuardConfigurationService.class);
         this.services = services;
-        loadConfig();
     }
 
-    /**
-     * Internal method to load the required configuration settings
-     *
-     * @throws OXException
-     */
-    private void loadConfig() throws OXException {
-        // Depreciating publicPGPDirectory.  Now using trustedPGPDirectory
-        String urlStrings = guardConfigService.getProperty(GuardProperty.publicPGPDirectory) + "," + guardConfigService.getProperty(GuardProperty.trustedPGPDirectory);
-        this.configuredRemoteHKPServers = getRemoteHKPServers(urlStrings);
-        this.untrustedRemoteHKPServers = getRemoteHKPServers(guardConfigService.getProperty(GuardProperty.untrustedPGPDirectory));
+    private Collection<String> getConfiguredRemoteServers(int userId, int cid) throws OXException {
+        String urlStrings =
+            guardConfigService.getProperty(GuardProperty.publicPGPDirectory, userId, cid) + "," +
+                guardConfigService.getProperty(GuardProperty.trustedPGPDirectory, userId, cid);
+        return getRemoteHKPServers(urlStrings);
+    }
+
+    private Collection<String> getuntrustedRemoteServers(int userId, int cid) throws OXException {
+        return getRemoteHKPServers(guardConfigService.getProperty(GuardProperty.untrustedPGPDirectory, userId, cid));
     }
 
     /**
@@ -112,16 +104,16 @@ public class RemoteHKPClientService implements HKPClientService, Reloadable  {
         return null;
     }
 
-    private RemoteKeyResult findInternal (String clientToken, Long id, String email, int timeout) throws Exception {
+    private RemoteKeyResult findInternal(String clientToken, Long id, String email, int userId, int cid, int timeout) throws Exception {
         String search = LongUtil.longToHexString(id);
         TimeTracker timer = new TimeTracker(timeout);
-        PGPPublicKeyRing ring = findById (clientToken, configuredRemoteHKPServers, search, timeout);
+        PGPPublicKeyRing ring = findById(clientToken, getConfiguredRemoteServers(userId, cid), search, timeout);
         if (ring != null) {
             logger.debug("Remote key found in trusted HKP server");
             return new RemoteKeyResult (ring, HKPKeySources.TRUSTED_HKP_REMOTE_SERVER);
         }
         else {
-            ring = findById (clientToken, untrustedRemoteHKPServers, search, timer.getRemaining());
+            ring = findById(clientToken, getuntrustedRemoteServers(userId, cid), search, timer.getRemaining());
             if (ring != null) {
                 logger.debug("Remote keys found in public HKP server");
                 return new RemoteKeyResult (ring, HKPKeySources.PUBLIC_HKP_REMOTE_SERVER);
@@ -129,7 +121,7 @@ public class RemoteHKPClientService implements HKPClientService, Reloadable  {
         }
         RemoteKeyResult result = null;
         if (delegate != null) {
-            result = delegate.find(clientToken, email, id, timer.getRemaining());
+            result = delegate.find(clientToken, email, id, userId, cid, timer.getRemaining());
         }
         return result;
     }
@@ -142,19 +134,19 @@ public class RemoteHKPClientService implements HKPClientService, Reloadable  {
      * @return
      * @throws Exception
      */
-    private Collection<RemoteKeyResult> findAllInternal(String clientToken, String email, int timeout) throws Exception {
+    private Collection<RemoteKeyResult> findAllInternal(String clientToken, String email, int userId, int cid, int timeout) throws Exception {
 
         //Searching configured HKP servers
         try {
             TimeTracker timer = new TimeTracker(timeout);
             // First check the trusted configured HKP servers
-            Collection<PGPPublicKeyRing> ret = findByEmail(clientToken, configuredRemoteHKPServers, email, timeout);
+            Collection<PGPPublicKeyRing> ret = findByEmail(clientToken, getConfiguredRemoteServers(userId, cid), email, timeout);
             if (ret != null && ret.size() > 0) {
                 logger.debug("Remote keys found in trusted HKP server");
                 return RemoteKeyResult.createCollectionFrom(ret, HKPKeySources.TRUSTED_HKP_REMOTE_SERVER);
             } else {
                 // If not found, then check the untrusted servers.
-                ret = findByEmail(clientToken, untrustedRemoteHKPServers, email, timer.getRemaining());
+                ret = findByEmail(clientToken, getuntrustedRemoteServers(userId, cid), email, timer.getRemaining());
                 if (ret != null && ret.size() > 0) {
                     logger.debug("Remote keys found in public HKP server");
                     return RemoteKeyResult.createCollectionFrom(ret, HKPKeySources.PUBLIC_HKP_REMOTE_SERVER);
@@ -165,48 +157,27 @@ public class RemoteHKPClientService implements HKPClientService, Reloadable  {
             logger.error("Error querying remote HKP server", e);
         }
         if (delegate != null) {
-            return delegate.find(clientToken, email, timeout);
+            return delegate.find(clientToken, email, userId, cid, timeout);
         }
         return null;
     }
 
     @Override
-    public Collection<RemoteKeyResult> find(String clientToken, String email, int timeout) throws OXException {
+    public Collection<RemoteKeyResult> find(String clientToken, String email, int userId, int cid, int timeout) throws OXException {
         try {
-            return findAllInternal(clientToken, email, timeout);
+            return findAllInternal(clientToken, email, userId, cid, timeout);
         } catch (Exception e) {
             throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
     }
 
     @Override
-    public RemoteKeyResult find(String clientToken, String email, Long id, int timeout) throws OXException {
+    public RemoteKeyResult find(String clientToken, String email, Long id, int userId, int cid, int timeout) throws OXException {
         try {
-            return findInternal(clientToken, id, email, timeout);
+            return findInternal(clientToken, id, email, userId, cid, timeout);
         } catch (Exception e) {
             throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
     }
 
-    /* (non-Javadoc)
-     * @see com.openexchange.config.Reloadable#reloadConfiguration(com.openexchange.config.ConfigurationService)
-     */
-    @Override
-    public void reloadConfiguration(ConfigurationService configService) {
-        try {
-            loadConfig();
-        }
-        catch (OXException e){
-            logger.error("Error reloading HKP client configuration.",e);
-        }
-    }
-
-    /* (non-Javadoc)
-     * @see com.openexchange.config.Reloadable#getInterests()
-     */
-    @Override
-    public Interests getInterests() {
-        return DefaultInterests.builder().propertiesOfInterest("com.openexchange.guard.*").configFileNames("guard-core.properties").build();
-    }
-
 }
