@@ -94,24 +94,28 @@ public class RemoteKeyResult {
      * Checks if all results in a given collection are considered to come from a trusted source
      *
      * @param keyResults The collection
+     * @param userId ID of the sender
+     * @param cid CID of the sender
      * @return True, if all results in the given collection come from a trusted source, false if a least one result does not come from a trusted source
      * @throws OXException
      */
-    public static boolean areTrusted(Collection<RemoteKeyResult> keyResults) throws OXException {
-        return getTrusted(keyResults).size() == keyResults.size();
+    public static boolean areTrusted(Collection<RemoteKeyResult> keyResults, int userId, int cid) throws OXException {
+        return getTrusted(keyResults, userId, cid).size() == keyResults.size();
     }
 
     /**
      * Gets the sub set of results which comes from a trusted source
      *
      * @param keyResults The results
+     * @param userId ID of the sender
+     * @param cid CID of the sender
      * @return A sub set of results which comes from a trusted source
      * @throws OXException
      */
-    public static Collection<RemoteKeyResult> getTrusted(Collection<RemoteKeyResult> keyResults) throws OXException {
+    public static Collection<RemoteKeyResult> getTrusted(Collection<RemoteKeyResult> keyResults, int userId, int cid) throws OXException {
         Collection<RemoteKeyResult> ret = new ArrayList<RemoteKeyResult>();
         for (RemoteKeyResult remoteKeyResult : keyResults) {
-            if (remoteKeyResult.getSource().isTrusted()) {
+            if (remoteKeyResult.getSource().isTrusted(userId, cid)) {
                 ret.add(remoteKeyResult);
             }
         }
