@@ -138,14 +138,14 @@ public class OGPGPKey {
     }
 
     public static String keyIdsAsString(List<String> keyIds) {
-        String ret = "";
+        StringBuilder sb = new StringBuilder();
         for (int i = 0; i < keyIds.size(); i++) {
             if(i > 0) {
-                ret += " ";
+                sb.append(" ");
             }
-            ret += keyIds.get(i);
+            sb.append(keyIds.get(i));
         }
-        return ret;
+        return sb.toString();
     }
 
     public String getKeyIdsAsString() {
