@@ -94,7 +94,7 @@ public class GuardKeySources {
      * @param keySourceFactory
      */
     public static void initialize(KeySourceFactory keySourceFactory) {
-        UNKNOWN = keySourceFactory.create("UNKNOWN", 0);
+        UNKNOWN = keySourceFactory.create("UNKNOWN", null);
         GUARD = keySourceFactory.create("GUARD_KEY_PAIR", GuardProperty.trustLevelGuard);
         GUARD_USER_UPLOADED = keySourceFactory.create("GUARD_USER_UPLOADED",GuardProperty.trustLevelGuardUserUploaded);
         GUARD_USER_SHARED = keySourceFactory.create("GUARD_USER_SHARED", GuardProperty.trustLevelGuardUserShared);
