@@ -50,6 +50,8 @@
 package com.openexchange.guard.keymanagement.commons.trust;
 
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.keymanagement.commons.osgi.Services;
 
 /**
@@ -64,17 +66,17 @@ import com.openexchange.guard.keymanagement.commons.osgi.Services;
 public class KeySource {
 
     private final String name;
-    private final int trustLevel;
+    private final GuardProperty sourceType;
 
     /**
      * Initializes a new {@link KeySource}.
      *
      * @param name The name of the {@link KeySource}
-     * @param trustLevel The level of trust
+     * @param sourceType GuardProperty for the sourceType
      */
-    public KeySource(String name, int trustLevel) {
+    public KeySource(String name, GuardProperty sourceType) {
         this.name = name;
-        this.trustLevel = trustLevel;
+        this.sourceType = sourceType;
     }
 
     /**
@@ -86,13 +88,16 @@ public class KeySource {
         return name;
     }
 
+
     /**
      * Gets the trustLevel
      *
      * @return The trustLevel
      */
-    public int getTrustLevel() {
-        return trustLevel;
+    public int getTrustLevel(int userId, int cid) {
+        if (sourceType == null)
+            return 0;
+        return Services.getService(GuardConfigurationService.class).getIntProperty(sourceType, userId, cid);
     }
 
     /**
@@ -101,9 +106,12 @@ public class KeySource {
      * @return True, if the source is a trusted source, false otherwise
      * @throws OXException
      */
-    public boolean isTrusted() throws OXException {
+    public boolean isTrusted(int userId, int cid) throws OXException {
+        if (sourceType == null)
+            return false;
         KeySourceTrustValidatorFactory factory = Services.getService(KeySourceTrustValidatorFactory.class);
-        KeySourceTrustValidator keySourceTrustValidator = factory.create();
-        return keySourceTrustValidator.isTrusted(this);
+        KeySourceTrustValidator keySourceTrustValidator = factory.create(userId, cid);
+        return keySourceTrustValidator.isTrusted(this, userId, cid);
     }
+
 }
