@@ -52,7 +52,6 @@ package com.openexchange.guard.keymanagement.keysources;
 import java.io.IOException;
 import java.io.StringReader;
 import java.util.Date;
-import java.util.Objects;
 import org.bouncycastle.crypto.AsymmetricCipherKeyPair;
 import org.bouncycastle.crypto.util.PrivateKeyFactory;
 import org.bouncycastle.crypto.util.PublicKeyFactory;
@@ -64,12 +63,15 @@ import org.bouncycastle.openssl.PEMParser;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.cipher.GuardCipherAlgorithm;
+import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.common.java.Strings;
 import com.openexchange.guard.keymanagement.keysources.exceptions.KeySourcesExceptionCodes;
-import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.keymanagement.services.KeyPairSource;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
 import com.openexchange.guard.keymanagement.storage.KeyCacheStorage;
+import com.openexchange.server.ServiceLookup;
 
 /**
  * {@link DbCachingKeyPairSource} defines a {@link KeyPairSource} which gets pre generated key pairs from the {@link KeyCacheStorage}
@@ -79,10 +81,8 @@ import com.openexchange.guard.keymanagement.storage.KeyCacheStorage;
  */
 public class DbCachingKeyPairSource implements KeyPairSource {
 
+    private ServiceLookup services;
     private static final Logger logger = LoggerFactory.getLogger(DbCachingKeyPairSource.class);
-    private final GuardCipherService guardCipherService;
-    private final GuardMasterKeyService guardMasterKeyService;
-    private final KeyCacheStorage keyCacheStorage;
 
     /**
      *
@@ -91,10 +91,8 @@ public class DbCachingKeyPairSource implements KeyPairSource {
      * @param guardCipherService The service used for decrypting pre-generated keys
      * @param guardMasterKeyService The service used for getting the master key in order to decrypt pre-generated keys
      */
-    public DbCachingKeyPairSource(GuardCipherService guardCipherService, GuardMasterKeyService guardMasterKeyService, KeyCacheStorage keyCacheStorage) {
-        this.guardCipherService = Objects.requireNonNull(guardCipherService, "guardCipherService must not be null");
-        this.guardMasterKeyService = Objects.requireNonNull(guardMasterKeyService, "guardMasterKeyService must not be null");
-        this.keyCacheStorage = Objects.requireNonNull(keyCacheStorage, "keyCacheStorage must not be null");
+    public DbCachingKeyPairSource(ServiceLookup services) {
+        this.services = services;
     }
 
     /**
@@ -104,6 +102,7 @@ public class DbCachingKeyPairSource implements KeyPairSource {
      * @throws OXException
      */
     private synchronized String getKeyData() throws OXException {
+        KeyCacheStorage keyCacheStorage = services.getServiceSafe(KeyCacheStorage.class);
         return keyCacheStorage.popNext();
     }
 
@@ -115,8 +114,10 @@ public class DbCachingKeyPairSource implements KeyPairSource {
      * @throws OXException
      */
     private String decryptKeyData(String keyData) throws OXException {
+        GuardCipherService guardCipherService = services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
+        MasterKeyService mkeyService = services.getServiceSafe(MasterKeyService.class);
         if (!Strings.isEmpty(keyData)) {
-            String decryptedKeyData = guardCipherService.decrypt(keyData, guardMasterKeyService.getMasterKey().getRC(), "key");
+            String decryptedKeyData = guardCipherService.decrypt(keyData, mkeyService.getMasterKey(0, false).getRC(), "key");
             return decryptedKeyData.isEmpty() ? null : decryptedKeyData;
         }
         else {
