@@ -57,6 +57,7 @@ import java.security.PrivateKey;
 import java.security.spec.InvalidKeySpecException;
 import java.security.spec.PKCS8EncodedKeySpec;
 import java.util.Collection;
+import java.util.List;
 import java.util.Objects;
 import org.bouncycastle.openpgp.PGPException;
 import org.bouncycastle.openpgp.PGPPrivateKey;
@@ -76,12 +77,13 @@ import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.MasterKey;
 import com.openexchange.guard.keymanagement.commons.PGPKeys;
 import com.openexchange.guard.keymanagement.commons.exceptions.KeysExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
-import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
 import com.openexchange.guard.keymanagement.services.PasswordChangeService;
 import com.openexchange.guard.keymanagement.services.RevocationReason;
 import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardKeyCreationExceptionCodes;
@@ -388,13 +390,13 @@ public class GuardKeyServiceImpl implements GuardKeyService {
             KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
             GuardKeys currentKey = ogKeyTableStorage.getCurrentKeyForUser(id, cid);
             if (currentKey != null && !Strings.isEmpty(currentKey.getRecovery())) {
-                GuardMasterKeyService masterKeyService = Services.getService(GuardMasterKeyService.class);
+                MasterKeyService masterKeyService = Services.getService(MasterKeyService.class);
                 GuardCipherService rsaCipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.RSA);
-                GuardKeys masterKeys = ogKeyTableStorage.getGuardDaemonKey();
+                MasterKey masterKeys = masterKeyService.getMasterKey(currentKey.getMasterKeyIndex(), true);
                 if (masterKeys == null) {
                     throw GuardMasterKeyExceptionCodes.UNABLE_TO_RETIREVE_MASTER_PASSWORD.create();
                 }
-                PrivateKey privateKey = decryptPrivateKey(masterKeys.getEncodedPrivate(), masterKeyService.getMasterKey().getMC(), masterKeys.getSalt());
+                PrivateKey privateKey = decryptPrivateKey(masterKeys.getMasterEncodedPrivate(), masterKeys.getMC(), masterKeys.getMasterSalt());
                 if (privateKey == null) {
                     throw new Exception("Bad master key");
                 }
@@ -405,7 +407,7 @@ public class GuardKeyServiceImpl implements GuardKeyService {
                 }
                 GuardCipherService aesCipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
                 String rsapub = currentKey.getEncodedPublic();
-                hash = aesCipherService.decrypt(encrhash, masterKeyService.getMasterKey().getRC() + (rsapub == null ? "" : Integer.toString(rsapub.hashCode())), currentKey.getSalt());
+                hash = aesCipherService.decrypt(encrhash, masterKeys.getRC() + (rsapub == null ? "" : Integer.toString(rsapub.hashCode())), currentKey.getSalt());
             }
         } catch (Exception ex) {
             LOG.error("Error recovering the password hash for " + cid + "/" + id, ex);
@@ -462,18 +464,16 @@ public class GuardKeyServiceImpl implements GuardKeyService {
      */
     @Override
     public boolean storeQuestion(int id, int cid, String question, String answer) throws OXException {
-        GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
-        String encranswer = null;
-        if (answer != null && !question.equals("")) {
-            GuardMasterKeyService masterKeyService = Services.getService(GuardMasterKeyService.class);
-            encranswer = cipherService.encrypt(answer, masterKeyService.getMasterKey().getRC(), question);
+        if (answer == null || question.equals("")) {
+            return true;
         }
-        try {
-            KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
-            ogKeyTableStorage.updateQuestionForUser(id, cid, question, encranswer);
-        } catch (Exception e) {
-            LOG.error("Error while storing reminder question", e);
-            return false;
+        String encranswer = null;
+        KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
+        MasterKeyService masterKeyService = Services.getService(MasterKeyService.class);
+        List<GuardKeys> keys = ogKeyTableStorage.getKeysForUser(id, cid);
+        for (GuardKeys key: keys) {
+            encranswer = masterKeyService.getRcEncryted(answer, question, key.getMasterKeyIndex());
+            ogKeyTableStorage.updateQuestionForKey(id, cid, question, encranswer, key.getKeyid());
         }
         return true;
     }
@@ -494,7 +494,7 @@ public class GuardKeyServiceImpl implements GuardKeyService {
     public void updateAnswerQuestionForUser(GuardKeys key) throws OXException {
         KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
         // Answer is already encrypted with the question, no need to re-encrypt
-        ogKeyTableStorage.updateQuestionForUser(key.getUserid(), key.getContextid(), key.getQuestion(), key.getAnswer());
+        ogKeyTableStorage.updateQuestionForKey(key.getUserid(), key.getContextid(), key.getQuestion(), key.getAnswer(), key.getKeyid());
     }
 
     /*
