@@ -79,8 +79,10 @@ import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.KeyCreationService;
 import com.openexchange.guard.keymanagement.services.KeyPairSource;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
 import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardKeyCreationExceptionCodes;
 import com.openexchange.guard.update.internal.GuardKeysUpdater;
+import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.encoding.Base64;
 
 /**
@@ -97,10 +99,9 @@ public class KeyCreationServiceImpl implements KeyCreationService {
     private static int[] PREFERRED_COPMRESSION = new int[] { CompressionAlgorithmTags.ZLIB, CompressionAlgorithmTags.BZIP2, CompressionAlgorithmTags.ZIP, CompressionAlgorithmTags.UNCOMPRESSED };
     private final int keyExpirationDays;
     private final int symmetricKeyAlgorithm;
-    private final GuardCipherService cipherService;
-    private final GuardKeyService keyService;
     private KeyPairSource defaultKeyPairSource;
-    private final KeyRecoveryService keyRecoveryService;
+    private final ServiceLookup services;
+    private GuardCipherService cipherService;
 
     /**
      * Initializes a new {@link KeyCreationServiceImpl}.
@@ -111,19 +112,24 @@ public class KeyCreationServiceImpl implements KeyCreationService {
      * @param keyExpirationDays The amount of days a new Key should be valid
      * @param symmetricKeyAlgorithm The ID of the symmetric encryption algorithm used for password protecting new {@link GuardKeys} instances.
      */
-    public KeyCreationServiceImpl(GuardCipherService cipherService,
-                                  GuardKeyService keyService,
-                                  KeyRecoveryService keyRecoveryService,
+    public KeyCreationServiceImpl(ServiceLookup services, GuardCipherService cipherService,
                                   int keyExpirationDays,
                                   int symmetricKeyAlgorithm) {
 
+        this.services = services;
         this.cipherService = cipherService;
-        this.keyService = keyService;
-        this.keyRecoveryService = keyRecoveryService;
         this.keyExpirationDays = keyExpirationDays;
         this.symmetricKeyAlgorithm = symmetricKeyAlgorithm;
     }
 
+    private KeyRecoveryService getKeyRecoveryService() throws OXException {
+        return services.getServiceSafe(KeyRecoveryService.class);
+    }
+
+    private MasterKeyService getMasterKeyService() throws OXException {
+        return services.getServiceSafe(MasterKeyService.class);
+    }
+
     /**
      * Internal method for creating a recovery token for the new key
      *
@@ -133,7 +139,7 @@ public class KeyCreationServiceImpl implements KeyCreationService {
      * @throws OXException
      */
     private String createKeyRecovery(GuardKeys keys, String password) throws OXException {
-        return keyRecoveryService.createRecovery(keys, password);
+        return getKeyRecoveryService().createRecovery(keys, password);
     }
 
     private String encryptPrivateKey(PrivateKey privateKey, String password, String salt) throws OXException {
@@ -156,6 +162,16 @@ public class KeyCreationServiceImpl implements KeyCreationService {
         this.defaultKeyPairSource = keyPairSource;
     }
 
+    /*
+     * (non-Javadoc)
+     *
+     * @see com.openexchange.guard.keymanagement.services.KeyCreationService#create(java.lang.String, java.lang.String, char[])
+     */
+    @Override
+    public GuardKeys create(int userid, int contextid, String name, String email, String password, Locale locale, boolean markAsCurrent, boolean createRecovery, int oxUserId, int oxCid) throws OXException {
+        return create(this.defaultKeyPairSource, userid, contextid, name, email, password, locale, markAsCurrent, createRecovery, oxUserId, oxCid);
+    }
+
     /*
      * (non-Javadoc)
      *
@@ -163,7 +179,8 @@ public class KeyCreationServiceImpl implements KeyCreationService {
      */
     @Override
     public GuardKeys create(int userid, int contextid, String name, String email, String password, Locale locale, boolean markAsCurrent, boolean createRecovery) throws OXException {
-        return create(this.defaultKeyPairSource, userid, contextid, name, email, password, locale, markAsCurrent, createRecovery);
+        // Create keys for non-guests users.
+        return create(this.defaultKeyPairSource, userid, contextid, name, email, password, locale, markAsCurrent, createRecovery, 0, 0);
     }
 
     /*
@@ -172,7 +189,7 @@ public class KeyCreationServiceImpl implements KeyCreationService {
      * @see com.openexchange.guard.keymanagement.services.KeyCreationService#create(com.openexchange.guard.keymanagement.services.KeyPairCreationStrategy, java.lang.String, java.lang.String, java.lang.String)
      */
     @Override
-    public GuardKeys create(KeyPairSource keyPairSource, int userid, int contextid, String name, String email, String password, Locale locale, boolean markAsCurrent, boolean createRecovery) throws OXException {
+    public GuardKeys create(KeyPairSource keyPairSource, int userid, int contextid, String name, String email, String password, Locale locale, boolean markAsCurrent, boolean createRecovery, int oxUserId, int oxCid) throws OXException {
 
         try {
             long start = System.currentTimeMillis();
@@ -249,11 +266,12 @@ public class KeyCreationServiceImpl implements KeyCreationService {
             keys.setContextid(contextid);
             keys.setLocale(locale);
             keys.setCurrent(markAsCurrent);
+            keys.setMasterKeyIndex(contextid >= 0 ? getMasterKeyService().getIndexForUser(userid, contextid) : getMasterKeyService().getIndexForUser(oxUserId, oxCid));
             keys.setRecovery(createRecovery ? createKeyRecovery(keys, password) : "");
             JsonObject version = new JsonObject();
             version.addProperty("version", GuardKeysUpdater.getCurrentVersion());
             keys.setMisc(version.toString());
-
+            keys.setKeyid(keys.getPGPPublicKeyRing().getPublicKey().getKeyID());
             LOG.debug("Created PGP/RSA Keys at " + start);
             return keys;
         } catch (PGPException e) {
