@@ -74,6 +74,7 @@ import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.KeyImportService;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
 import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardKeyImportExceptionCodes;
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
@@ -247,7 +248,7 @@ public class KeyImportServiceImpl implements KeyImportService {
 
         //apply public key ring
         newKeys.setPGPPublicKeyRing(createPublicKeyRingFromPrivateKeyRing(secretKeyRing));
-
+        newKeys.setKeyid(newKeys.getPGPPublicKeyRing().getPublicKey().getKeyID());
         //Verify that the password works
         if(!PGPUtil.verifyPassword(newKeys.getPGPSecretKey(), newPassword, newKeys.getSalt())) {
             throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
@@ -272,7 +273,13 @@ public class KeyImportServiceImpl implements KeyImportService {
             guardKeyService.addNewKey(newKeys);
             if (currentKey != null) {
                 guardKeyService.updateSettingsForUser(currentKey);
-                guardKeyService.updateAnswerQuestionForUser(currentKey);
+                newKeys.setQuestion(currentKey.getQuestion());
+                MasterKeyService mKeyService = Services.getService(MasterKeyService.class);
+                if (mKeyService != null) {
+                    String decrypted = mKeyService.getRcDecrypted(currentKey.getAnswer(), currentKey.getQuestion(), currentKey.getMasterKeyIndex());
+                    newKeys.setAnswer(mKeyService.getRcEncryted(decrypted, newKeys.getQuestion(), newKeys.getMasterKeyIndex()));
+                }
+                guardKeyService.updateAnswerQuestionForUser(newKeys);
             }
         }
         else { //Merge existing keys
