@@ -65,12 +65,14 @@ import com.openexchange.guard.keymanagement.services.lookup.RecipKeyLookupStrate
 public class GuestRecipKeyLookupStrategy implements RecipKeyLookupStrategy {
 
     private final int senderContextId;
+    private final int senderUserId;
 
     /**
      * Initializes a new {@link GuestRecipKeyLookupStrategy}.
      * @param senderContextId
      */
-    public GuestRecipKeyLookupStrategy(int senderContextId) {
+    public GuestRecipKeyLookupStrategy(int senderUserId, int senderContextId) {
+        this.senderUserId = senderUserId;
         this.senderContextId = senderContextId;
     }
 
@@ -80,7 +82,7 @@ public class GuestRecipKeyLookupStrategy implements RecipKeyLookupStrategy {
         recipKey.setEmail(email);
         recipKey.setCid(senderContextId * -1);
         GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-        recipKey.setLang(configService.getProperty(GuardProperty.defaultLanguage));
+        recipKey.setLang(configService.getProperty(GuardProperty.defaultLanguage, senderUserId, senderContextId));
         recipKey.setPgp(false); //The user is not a regular PGP user but an external guest
         return recipKey;
     }
