@@ -86,6 +86,16 @@ public interface PublicExternalKeyService {
      */
     List<OGPGPKeyRing> get(int userId, int contextId) throws OXException;
 
+    /**
+     * Gets the uploaded public PGP key ring with the specified id for the given user
+     * @param userId The ID of the user
+     * @param contextId The context of the user
+     * @param hexid The identifier of the key ring to delete
+     * @return The uploaded PGP key ring for the given user containing the given hexid, or null if no such key was found for the user.
+     * @throws OXException
+     */
+    OGPGPKeyRing get(int userId, int contextId, String hexid) throws OXException;
+
     /**
      * Adds new public PGP key rings for an external recipient
      *
