@@ -67,10 +67,12 @@ public interface RecipKeyService {
      *
      * @param lookupStrategy The strategy defining where/how to search
      * @param email The email address of the recipient
+     * @param userId The id of the sender
+     * @param cid The cid of the sender
      * @return The {@link RecipKey} for the given email, or null if no such {@link RecipKey} was found
      * @throws OXException
      */
-    RecipKey getRecipKey(RecipKeyLookupStrategy lookupStrategy, String email) throws OXException;
+    RecipKey getRecipKey(RecipKeyLookupStrategy lookupStrategy, String email, int userId, int cid) throws OXException;
 
     /**
      * Searches for a recipient key ({@link RecipKey}) by email using a default {@link RecipKeyLookupStrategy} set by the implementing class.
@@ -86,10 +88,12 @@ public interface RecipKeyService {
     /**
      * Searches for a recipient key ({@link RecipKey}) by email using a default {@link RecipKeyLookupStrategy} set by the implementing class, but will only return "internal" recipient (i.e. only regular OX Users)
      *
+     * @param senderUserId The user user ID of the user who wants to lookup for a recipient key
+     * @param senderContextId The context ID of the user who wants to lookup for a recipient key
      * @param email The email address of the recipient
      * @return The {@link RecipKey} for the given email, or null if no such {@link RecipKey} was found
      * @throws OXException
      */
-    RecipKey getInternalRecipKey(String email) throws OXException;
+    RecipKey getInternalRecipKey(int senderUserId, int senderContextId, String email) throws OXException;
 
 }
