@@ -102,6 +102,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             key.setCurrent(resultSet.getBoolean("current"));
             key.setLanguage(resultSet.getString("lang"));
             key.setRecovery(resultSet.getString("Recovery"));
+            key.setMasterKeyIndex(resultSet.getInt("mKeyIndex"));
             if (key.getRecovery() != null) {
                 if (key.getRecovery().equals("-1") || (key.getLastup() == null)) {
                     key.setPasswordNeeded(true);
@@ -381,29 +382,6 @@ public class KeyTableStorageImpl implements KeyTableStorage {
         }
     }
 
-    @Override
-    public GuardKeys getGuardDaemonKey() throws OXException {
-        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
-
-        Connection connection = guardDatabaseService.getReadOnlyForGuard();
-        PreparedStatement stmt = null;
-        ResultSet resultSet = null;
-        try {
-            stmt = connection.prepareStatement(KeyTableSql.SELECT_GUARD_DAEMON_KEY_STMT);
-
-            resultSet = stmt.executeQuery();
-            if (resultSet.next()) {
-                return createKey(resultSet);
-            }
-            return null;
-        } catch (SQLException e) {
-            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
-        } finally {
-            DBUtils.closeSQLStuff(resultSet, stmt);
-            guardDatabaseService.backReadOnlyForGuard(connection);
-        }
-    }
-
     @Override
     public void insert(GuardKeys key, boolean setLastMod) throws OXException {
         insert(key, setLastMod, 0);
@@ -505,6 +483,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             stmt.setBoolean(16, key.isCurrent());
             stmt.setString(17, key.getMisc());
+            stmt.setInt(18, key.getMasterKeyIndex());
 
             stmt.executeUpdate();
         } catch (SQLException e) {
@@ -665,7 +644,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
     }
 
     @Override
-    public void updateQuestionForUser(int userId, int contextId, String question, String answer) throws OXException {
+    public void updateQuestionForKey(int userId, int contextId, String question, String answer, long keyId) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
 
         GuardConnectionWrapper connectionWrapper = guardDatabaseService.getWritable(userId, contextId, 0);
@@ -676,7 +655,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             stmt.setString(2, answer);
             stmt.setInt(3, userId);
             stmt.setInt(4, contextId);
-
+            stmt.setLong(5, keyId);
             stmt.executeUpdate();
         } catch (SQLException e) {
             throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
@@ -1041,6 +1020,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
                     key.setPasswordNeeded(true);
                 }
             }
+            key.setMasterKeyIndex(rs.getInt("mKeyIndex"));
             return key;
         } catch (SQLException e) {
             throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
