@@ -50,7 +50,7 @@
 package com.openexchange.guard.keymanagement.storage.impl.remotekeys;
 
 public class RemoteKeyCacheSql {
-    public static final String SELECT_BY_EMAIL_STMT = "SELECT ring, keysource from remote_key_cache rkc INNER JOIN remote_keys rk ON rkc.id = rk.ref WHERE rk.email = ? GROUP BY rkc.id";
+    public static final String SELECT_BY_EMAIL_STMT = "SELECT ring, keysource from remote_key_cache rkc INNER JOIN remote_keys rk ON rkc.id = rk.ref WHERE rk.email = ?";
     public static final String SELECT_BY_ID_STMT = "SELECT ring, keysource from remote_key_cache rkc INNER JOIN remote_keys rk ON rkc.id = rk.ref WHERE rk.id = ?";
     public static final String INSERT_RING_DATA_STMT = "INSERT INTO remote_key_cache (id, ring, created) VALUES (?, ?, NOW()) ON DUPLICATE KEY UPDATE ring = ?";
     public static final String INSERT_RING_ID_STMT = "INSERT INTO remote_keys (id, email, ref, keysource) VALUES (?, ?, ?, ?) ON DUPLICATE KEY UPDATE ref = ?";
