@@ -198,14 +198,6 @@ public interface KeyTableStorage {
      */
     public GuardKeys getKeyForEmailAndContext(String email, int contextid, int shard) throws OXException;
 
-    /**
-     * Returns the guard server's own PGP key
-     *
-     * @return the guard server's PGP key
-     * @throws OXException due an error
-     */
-    public GuardKeys getGuardDaemonKey() throws OXException;
-
     /**
      * Inserts a new GuardKey
      *
@@ -293,9 +285,10 @@ public interface KeyTableStorage {
      * @param contextId the context id
      * @param question the new question
      * @param answer the new answer
+     * @param keyId the id of the key
      * @throws OXException
      */
-    public void updateQuestionForUser(int userId, int contextId, String question, String answer) throws OXException;
+    public void updateQuestionForKey(int userId, int contextId, String question, String answer, long keyId) throws OXException;
 
     /**
      * Updates the version of a key
