@@ -143,7 +143,7 @@ public class MailCreatorServiceImpl implements MailCreatorService {
         if (data == null) {
             data = "";
         }
-        emailText = emailText.replace("$plaintext", data.replace("\r", "<br>"));
+        emailText = emailText.replace("$plaintext", data.replace("\n", "<br>"));
         Gson g = new Gson();
         return (g.fromJson(emailText, JsonObject.class));
     }
@@ -335,7 +335,8 @@ public class MailCreatorServiceImpl implements MailCreatorService {
         return (templToEmail (templ, to, from, host, userid, cid));
     }
 
-    private JsonObject templToEmail (String templ, String to, List<String> from, String host, int userid, int cid) throws OXException {
+    @Override
+    public JsonObject templToEmail (String templ, String to, List<String> from, String host, int userid, int cid) throws OXException {
         JsonObject email = createBlankMail();
         email = addTo(email, to, to);
         email = addFrom(email, from.get(0), from.get(1));
@@ -377,8 +378,8 @@ public class MailCreatorServiceImpl implements MailCreatorService {
         // If no config cascade
         if (fromemail == null || fromemail.isEmpty()) {
             // Check if we have global configuration
-            String fromAddress = guardConfigService.getProperty(GuardProperty.passwordFromAddress);
-            String fromName = guardConfigService.getProperty(GuardProperty.passwordFromName);
+            String fromAddress = guardConfigService.getProperty(GuardProperty.passwordFromAddress, userid, cid);
+            String fromName = guardConfigService.getProperty(GuardProperty.passwordFromName, userid, cid);
             if (Strings.isNotEmpty(fromAddress)) {
                 if (Strings.isNotEmpty(fromName)) {
                     answer.add(fromName);
