@@ -146,4 +146,12 @@ public interface GuardMaintenanceMBean {
      */
     void changeUser(String email, String newEmail) throws MBeanException;
 
+    /**
+     * Creates new master key and returns index
+     * createMaster
+     *
+     * @throws MBeanException
+     */
+    int createMaster() throws MBeanException;
+
 }
