@@ -180,4 +180,14 @@ public class GuardMaintenanceMBeanImpl extends StandardMBean implements GuardMai
         }
 
     }
+
+    @Override
+    public int createMaster() throws MBeanException {
+        try {
+            return maintenanceService.createMasterKeys();
+        } catch (OXException e) {
+            throw new MBeanException(e);
+        }
+
+    }
 }
