@@ -93,9 +93,13 @@ public abstract class Encryptor {
     public String doEncryptToString() throws OXException {
         ByteArrayOutputStream wrapped_out = new ByteArrayOutputStream();
         try {
-            doEncrypt().writeTo(wrapped_out);
-            byte[] wrapped_bytes = wrapped_out.toByteArray();
-            return (new String (wrapped_bytes, "UTF-8"));
+            MimeMessage msg = doEncrypt();
+            if (msg != null) {
+                doEncrypt().writeTo(wrapped_out);
+                byte[] wrapped_bytes = wrapped_out.toByteArray();
+                return (new String (wrapped_bytes, "UTF-8"));
+            }
+            return "";
         } catch (IOException | MessagingException e) {
             throw MimeEncryptorExceptionCodes.SEND_EMAIL_ERROR.create(e.getMessage());
         }
