@@ -156,6 +156,9 @@ public class PGPProcessMime implements ProcessMime {
     @Override
     public String doEncrypt(GuardParsedMimeMessage msg, int userId, int contextId, String password) throws OXException {
 
+        final int originalUserId = userId;
+        final int originalContextId = contextId;
+
         //Assures appropriated Guard permissions for user
         // If doesn't have guard-mail, possible secure reply.  Verify all users have keys
         // No new users allowed.
@@ -210,17 +213,17 @@ public class PGPProcessMime implements ProcessMime {
                 if (!msg.isDraft() && autocryptService != null) {  // For emails being sent, attach all gossip headers
                     final InternetAddress addr = msg.getFromAddress();
                     String autocryptHeader =
-                        autocryptService.getOutgoingHeaderString(userId, contextId, addr == null ? null : addr.getAddress());
+                        autocryptService.getOutgoingHeaderString(userId, contextId, originalUserId, originalContextId, addr == null ? null : addr.getAddress());
                     if (autocryptHeader != null && !autocryptHeader.isEmpty()) {
                         msg.getMessage().addHeader("Autocrypt", autocryptHeader);
                     }
                     msg.setMessage(autocryptService.addGossipHeaders(msg.getMessage(), userId, contextId, allRecipts));
                 }
                 if (recips.size() > 0) {
-                    encryptor = new GuardPGPMimeEncryptor(pgpCryptoService, helpFileService, msg, recips, userId, contextId, password);
+                    encryptor = new GuardPGPMimeEncryptor(pgpCryptoService, helpFileService, msg, recips, userId, contextId, originalUserId, originalContextId, password);
                 } else {
                     if (guests.size() > 0) {  // No recips, but we had guests, we need to send this for the sent folder
-                        encryptor = new GuardPGPMimeEncryptor(pgpCryptoService, helpFileService, msg, guests, userId, contextId, password);
+                        encryptor = new GuardPGPMimeEncryptor(pgpCryptoService, helpFileService, msg, guests, userId, contextId, originalUserId, originalContextId, password);
                     }
                 }
             }
@@ -230,7 +233,7 @@ public class PGPProcessMime implements ProcessMime {
 
                 if(msg.senderIsGuest() && !msg.isDraft()) {
                     //Sending on behalf of a guest
-                    send(encryptedResult, msg.getSenderEmail(), userId, contextId, recips, msg.getSenderIP());
+                    send(encryptedResult, msg.getSenderEmail(), userId, contextId, originalUserId, originalContextId, recips, msg.getSenderIP());
 
                     //Remove the all recipients handled by Guard
                     return convertToString(removeRecipients(encryptedResult, allRecipts, origMessageID));
@@ -248,10 +251,10 @@ public class PGPProcessMime implements ProcessMime {
         }
     }
 
-    private void send(Message message, String senderEmail, int userId, int senderCid, ArrayList<RecipKey> recipients, String remoteIp) throws OXException {
+    private void send(Message message, String senderEmail, int guardUserId, int guardCid, int userId, int senderCid, ArrayList<RecipKey> recipients, String remoteIp) throws OXException {
         String fromAddress = getFromEmailAddress(recipients, senderEmail);
         for(RecipKey recipient : recipients) {
-            this.guardNotificationService.sendMessage(message, recipient.getEmail(), fromAddress, userId, senderCid, recipient.getLang(), remoteIp);
+            this.guardNotificationService.sendMessage(message, recipient.getEmail(), fromAddress, guardUserId, guardCid, userId, senderCid, recipient.getLang(), remoteIp);
         }
     }
 
@@ -349,10 +352,10 @@ public class PGPProcessMime implements ProcessMime {
      * @see com.openexchange.guard.mime.encryptor.ProcessMime#doDecrypt(com.openexchange.guard.mime.services.GuardParsedMimeMessage, java.lang.String)
      */
     @Override
-    public MimeMessage doDecrypt(MimeMessage message, int userId, int contextId, UserIdentity userIdentity) throws OXException {
+    public MimeMessage doDecrypt(MimeMessage message, UserIdentity userIdentity) throws OXException {
 
         //Assures appropriated Guard permissions for user
-        requirePermission(userId, contextId, false);
+        requirePermission(userIdentity.getOXUser().getId(), userIdentity.getOXUser().getContextId(), false);
 
         try {
             MimeParser mimeParser = new MimeParser(message);
