@@ -75,7 +75,7 @@ import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
-import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
 import com.openexchange.guard.mime.encryptor.osgi.Services;
 import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
 import com.openexchange.guard.pgpcore.services.PGPSigningService;
@@ -143,10 +143,10 @@ public class SignMime {
      * @return
      * @throws OXException
      */
-    public String decodeRSApassword(String epass) throws OXException {
+    public String decodeRSApassword(String epass, int userId, int cid) throws OXException {
         GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.RSA);
-        GuardMasterKeyService masterKeyService = Services.getService(GuardMasterKeyService.class);
-        return cipherService.decrypt(epass, masterKeyService.getMasterKey().getPrivateKey());
+        MasterKeyService masterKeyService = Services.getService(MasterKeyService.class);
+        return cipherService.decrypt(epass, masterKeyService.getMasterKey(userId, cid).getClientEncodedPrivate());
     }
 
     /**
