@@ -239,7 +239,7 @@ public class PGPInlineDecryptor extends Decryptor {
     private String getText(ByteArrayOutputStream decryptedContent, String type, boolean mdcVerified) throws OXException {
         String result = new String(decryptedContent.toByteArray(), StandardCharsets.UTF_8);
         if (!mdcVerified) {
-            if (guardConfigService.getBooleanProperty(GuardProperty.failForMissingMDC)) {
+            if (guardConfigService.getBooleanProperty(GuardProperty.failForMissingMDC, userIdentity.getOXUser().getId(), userIdentity.getOXUser().getContextId())) {
                 throw MimeEncryptorExceptionCodes.MISSING_MDC.create();
             }
             LOG.warn("PGP Inline message missing MDC integrity check data.  Stripping HTML");
