@@ -145,7 +145,7 @@ public class PGPMimeDecryptor extends Decryptor {
             final List<PGPSignatureVerificationResult> decrypt = decryptionResult.getSignatureVerificationResults();
             checkMissingHeaders(message, decodedMsg);
             if (!decryptionResult.getMDCVerifiacionResult().isPresent()) {
-                if (guardConfigService.getBooleanProperty(GuardProperty.failForMissingMDC)) {
+                if (guardConfigService.getBooleanProperty(GuardProperty.failForMissingMDC, userIdentity.getOXUser().getId(), userIdentity.getOXUser().getContextId())) {
                     throw MimeEncryptorExceptionCodes.MISSING_MDC.create();
                 } else {
                     try {
