@@ -93,8 +93,9 @@ public class HelpFileServiceImpl implements HelpFileService {
     private List<HelpAttach> getHelp(int userid, int cid, final String...languages) {
         final List<HelpAttach> helpfiles = new ArrayList<HelpAttach>();
         try {
-            String externalReaderPath = guardConfigurationService.getProperty(GuardProperty.externalReaderPath);
-            String oxURL = guardConfigurationService.getProperty(GuardProperty.externalEmailURL);
+            String externalReaderPath =
+                guardConfigurationService.getProperty(GuardProperty.externalReaderPath, userid, cid);
+            String oxURL = guardConfigurationService.getProperty(GuardProperty.externalEmailURL, userid, cid);
 
             for (int i = 0; i < languages.length; i++) {
                 final String lang = translationService.getAvailableCode(languages[i]);
