@@ -88,6 +88,7 @@ import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.notification.exceptions.GuardNotificationExceptionCodes;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.guard.translation.GuardTranslationService;
+import com.openexchange.mail.mime.MimeDefaultSession;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import net.htmlparser.jericho.Source;
 
@@ -117,7 +118,7 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
 
     @Override
     public void send(final JsonObject email, int senderUserId, int senderCid, final String senderIp) throws OXException {
-        send(email, null, "", senderUserId, senderCid, guardConfigService.getProperty(GuardProperty.defaultLanguage), getMessageID(senderUserId, senderCid), senderIp);
+        send(email, null, "", senderUserId, senderCid, guardConfigService.getProperty(GuardProperty.defaultLanguage, senderUserId, senderCid), getMessageID(senderUserId, senderCid), senderIp);
     }
 
     @Override
@@ -324,8 +325,8 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
     }
 
     @Override
-    public void sendMessage(final Message msg, final String toAddr, final String sender, int senderUserId, int senderCid, final String lang, final String senderIp) throws OXException {
-        final Session session = getSession(senderUserId, senderCid, isLocal(senderCid));
+    public void sendMessage(final Message msg, final String toAddr, final String sender, int guardSenderUserId, int guardSenderCid, int senderUserId, int senderCid, final String lang, final String senderIp) throws OXException {
+        final Session session = getSession(senderUserId, senderCid, isLocal(guardSenderCid));
         Transport transport;
         try {
             if (!sender.equals("")) {
@@ -376,7 +377,7 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
         final int port = guardConfigService.getIntProperty(GuardProperty.guestSMTPPort, userId, cid);
         final String username = guardConfigService.getProperty(GuardProperty.guestSMTPUsername, userId, cid);
 
-        final Properties prop = new Properties();
+        final Properties prop = MimeDefaultSession.getDefaultMailProperties();
         boolean authenticate = true;
         if (username.length() < 2) {
             authenticate = false;
