@@ -57,6 +57,7 @@ import com.openexchange.guard.notification.internal.GuardNotificationServiceImpl
 import com.openexchange.guard.notification.internal.Services;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.guard.translation.GuardTranslationService;
+import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import com.openexchange.osgi.HousekeepingActivator;
 
 /**
@@ -89,7 +90,7 @@ public class GuardNotificationActivator extends HousekeepingActivator {
             this.getService(GuardConfigurationService.class),
             this.getService(ConfigurationService.class).getBoolProperty(attachIpPropertyName, false)));
         logger.info("GuardNotificationService registered.");
-
+        trackService(SSLSocketFactoryProvider.class);
         openTrackers();
     }
 
