@@ -57,6 +57,7 @@ import org.bouncycastle.openpgp.PGPPublicKey;
 import org.bouncycastle.openpgp.PGPSecretKey;
 import org.slf4j.Logger;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.autocrypt.database.AutoCryptStorageService;
 import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
@@ -70,7 +71,7 @@ import com.openexchange.pgp.core.PGPDecrypter;
 import com.openexchange.pgp.core.PGPDecryptionResult;
 import com.openexchange.pgp.core.PGPEncrypter;
 import com.openexchange.pgp.core.PGPKeyRetrievalStrategy;
-import com.openexchange.pgp.core.PGPSymmetricDecrypter;
+import com.openexchange.pgp.core.PGPSessionKeyDecrypter;
 import com.openexchange.pgp.keys.common.PGPSymmetricKey;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
@@ -86,6 +87,7 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
     private static final Logger logger = org.slf4j.LoggerFactory.getLogger(PGPCryptoServiceImpl.class);
     private GuardKeyService guardKeyService;
     private OGPGPKeysStorage keyStorage;
+    private AutoCryptStorageService autocryptService;
 
     /**
      * Initializes a new {@link PGPCryptoServiceImpl}.
@@ -93,10 +95,11 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
      * @param pgpKeyRetrievalStrategy the strategy for retrieving keys for decryption.
      * @param recipientKeyRingRetrievalStrategy the strategy for retrieving keys for encryption
      */
-    public PGPCryptoServiceImpl(GuardKeyRingRetrievalStrategy recipientKeyRingRetrievalStrategy, GuardKeyService guardKeyService, OGPGPKeysStorage keyStorage) {
+    public PGPCryptoServiceImpl(GuardKeyRingRetrievalStrategy recipientKeyRingRetrievalStrategy, GuardKeyService guardKeyService, OGPGPKeysStorage keyStorage, AutoCryptStorageService autocryptService) {
         this.recipientKeyRingRetrievalStrategy = recipientKeyRingRetrievalStrategy;
         this.guardKeyService = guardKeyService;
         this.keyStorage = keyStorage;
+        this.autocryptService = autocryptService;
     }
 
     /**
@@ -106,7 +109,7 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
      * @return The strategy for the given key to use.
      */
     private PGPKeyRetrievalStrategy getKeyRetrievalStrategyFor(GuardKeys key) {
-        return new DefaultPGPKeyRetrievalStrategy(guardKeyService, keyStorage, key.getUserid(), key.getContextid());
+        return new DefaultPGPKeyRetrievalStrategy(guardKeyService, keyStorage, autocryptService, key.getUserid(), key.getContextid());
     }
 
     /**
@@ -117,7 +120,7 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
      */
     private PGPKeyRetrievalStrategy getKeyRetrievalStrategyFor(UserIdentity userIdentity) {
        if(userIdentity != null && userIdentity.isOXUser() && !userIdentity.getOXUser().isGuest()) {
-           return new DefaultPGPKeyRetrievalStrategy(guardKeyService, keyStorage, userIdentity.getOXUser().getId(), userIdentity.getOXUser().getContextId());
+           return new DefaultPGPKeyRetrievalStrategy(guardKeyService, keyStorage, autocryptService, userIdentity.getOXUser().getId(), userIdentity.getOXUser().getContextId());
        } else {
            return new DBKeyRetrievalStrategy(guardKeyService);
        }
@@ -340,7 +343,7 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
     public PGPDecryptionResult decrypt(InputStream input, OutputStream output, PGPSymmetricKey symmetricKey, UserIdentity recipient) throws OXException {
         try {
             logger.debug("Decrypting data with symmetric session key");
-            PGPSymmetricDecrypter symmetricDecrypter = new PGPSymmetricDecrypter(
+            PGPSessionKeyDecrypter symmetricDecrypter = new PGPSessionKeyDecrypter(
                 symmetricKey,
                 new PublicKeyOnlyKeyRingRetrievalStrategy(getKeyRetrievalStrategyFor(recipient)));
             return symmetricDecrypter.decrypt(input, output);
