@@ -98,8 +98,8 @@ public class PGPKeySigningServiceImpl implements PGPKeySigningService {
         return new DefaultPGPKeyRetrievalStrategy(guardKeyService,
             ogPGPKeysStorage,
             autocryptStorageService,
-            verifier.getOXGuardUser().getId(),
-            verifier.getOXGuardUser().getContextId());
+            verifier.getOXUser().getId(),
+            verifier.getOXUser().getContextId());
     }
 
     /**
