@@ -126,7 +126,8 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
     }
 
     private PGPKeyRetrievalStrategy getKeyRetrievalStrategyFor(UserIdentity user) {
-        int timeout = this.configurationService.getIntProperty(GuardProperty.remoteKeyLookupTimeout);
+        int timeout = this.configurationService.getIntProperty(GuardProperty.remoteKeyLookupTimeout,
+            user.getOXUser().getId(), user.getOXUser().getContextId());
 
         return new CompositePGPKeyRetrievalStrategy(
 
@@ -134,11 +135,15 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
             new DefaultPGPKeyRetrievalStrategy(guardKeyService,
                 keyStorage,
                 autocryptService,
-                user.getOXGuardUser().getId(),
-                user.getOXGuardUser().getContextId()),
+                user.getOXUser().getId(),
+                user.getOXUser().getContextId()),
 
             //..Look for public keys on _trusted_ HKP servers
-            new HKPPGPKeyRetrievalStrategy(hkpClient, timeout, HKPPGPKeyRetrievalStrategy.TrustMode.TRUSTED_ONLY)
+            new HKPPGPKeyRetrievalStrategy(hkpClient,
+                user.getOXUser().getId(),
+                user.getOXUser().getContextId(),
+                timeout,
+                HKPPGPKeyRetrievalStrategy.TrustMode.TRUSTED_ONLY)
 
         );
     }
@@ -306,6 +311,7 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
             return new PGPSignatureVerifier(getKeyRetrievalStrategyFor(userIdentity))
                 .verifySignatures(signedData, signature);
         } catch (Exception e) {
+            LOG.error("Error verifying signature", e);
             return Arrays.asList(new PGPSignatureVerificationResult(e.getMessage()));
         } finally {
             IOUtils.closeQuietly(signature);
@@ -378,7 +384,7 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
                                 }
                             } catch (OXException ex) {
                                 LOG.error("Problem checking inline signature in email", ex);
-                                return ret;
+                                return Collections.singletonList(new PGPSignatureVerificationResult("Unable to verify signature"));
                             }
                         } else {
                             // If not a text part or attachment, just add it back to the multipart
@@ -429,7 +435,7 @@ public class PGPMimeSigningServiceImpl implements PGPMimeSigningService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.pgpcore.services.PGPMimeSigningService#verify(javax.mail.internet.MimeMessage, com.openexchange.guard.user.UserIdentity)
      */
     @Override
