@@ -68,6 +68,7 @@ import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.pgpcore.services.exceptions.PGPCoreServicesExceptionCodes;
 import com.openexchange.guard.session.GuardSessionService;
 import com.openexchange.guard.user.OXGuardUser;
+import com.openexchange.guard.user.OXUser;
 import com.openexchange.guard.user.OXUserService;
 import com.openexchange.guard.user.UserIdentity;
 import com.openexchange.pgp.keys.common.PGPSymmetricKey;
@@ -182,7 +183,14 @@ public class TokenAuthenticationServiceImpl implements TokenAuthenticationServic
             final int userId = json.getInt("user_id");
             final int cid = json.getInt("cid");
             ret.setOXGuardUser(new OXGuardUser(userId, cid));
-            ret.setOXUser(guardUserService.getUser(cid, userId));
+            if (json.has("oxUserId") && json.has("oxCid")) {
+                ret.setOXUser(new OXUser(ret.getIdentity(), json.getInt("oxUserId"), json.getInt("oxCid"), null, false, null));
+            } else {
+                if (cid < 0) {  // Guest user, try lookup
+                    ret.setOXUser(guardUserService.getUser(cid, userId));
+                } else
+                    ret.setOXUser(new OXUser(ret.getIdentity(), userId, cid, null, false, null));
+            }
         }
         return ret;
     }
