@@ -53,8 +53,8 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.ArrayList;
 import java.util.List;
-import org.json.JSONException;
 import org.bouncycastle.openpgp.PGPPublicKey;
+import org.json.JSONException;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
@@ -145,6 +145,8 @@ public class SharingServiceImpl implements SharingService {
                     rKey.setEmail(email);
                     rKey.setPgp(true);
                     rKey.setGuest(true);
+                    rKey.setSenderCid(ownerKey.getContextid());
+                    rKey.setSenderUserId(ownerKey.getUserid());
                 }
                 RecipKey newKey = Services.getService(AccountCreationService.class).createUserFor(rKey);
                 if (newKey == null) {
