@@ -115,16 +115,6 @@ public interface Storage {
      */
     String getDirectoryPrefix(int userId, int contextId, int shardId) throws OXException;
 
-    /**
-     * This is to get directory prefix for guard proprietary, which had an error. Remove in near future
-     *
-     * @param userid
-     * @param contextid
-     * @param shardid
-     * @return
-     */
-    String getDirectoryPrefix2(int userId, int contextId, int shardId) throws OXException;
-
     InputStream getObjectStream(String location) throws OXException;
 
     InputStream getObjectStream(String directoryPrefix, String ObjId) throws OXException;
@@ -157,7 +147,7 @@ public interface Storage {
      * @throws IOException
      * @throws OXException if the GuardConfigurationService is absent
      */
-    Boolean writeObj(String directoryPrefix, String ObjId, byte[] data) throws OXException;
+    String writeObj(String directoryPrefix, String ObjId, byte[] data) throws OXException;
 
     /**
      * This method returns the shard ID contained in the given directoryPrefix
