@@ -49,6 +49,8 @@
 
 package com.openexchange.guard.user;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import com.openexchange.pgp.keys.common.PGPSymmetricKey;
 
 /**
@@ -64,6 +66,7 @@ public class UserIdentity {
     private PGPSymmetricKey symmetricKey;
     private OXUser          oxUser;
     private OXGuardUser     oxGuardUser;
+    private static Logger LOG = LoggerFactory.getLogger(UserIdentity.class);
 
     /**
      * Initializes a new {@link UserIdentity}.
@@ -151,6 +154,13 @@ public class UserIdentity {
      * @return The OX Appsuite user, or null, if this entity is not related to a regular OX Appsuite account.
      */
     public OXUser getOXUser() {
+        if (this.oxUser == null) {
+            if (this.oxGuardUser != null) {
+                LOG.error("Call for OX User which is null.  Using Guard user.  Please report");
+                // Fallback to Guard user
+                return new OXUser(this.identity, this.oxGuardUser.getId(), this.oxGuardUser.getContextId(), null, this.oxGuardUser.getContextId() < 0, null);
+            }
+        }
         return this.oxUser;
     }
 
