@@ -208,7 +208,7 @@ public class WKSClient {
             }
             HttpClientUtils.closeQuietly(client);
             if (timer != null)
-                timer.cancel();  // Cleanup for request timer
+                timer.cancel();
         }
         return Collections.emptyList();
     }
