@@ -89,15 +89,15 @@ public class WKSClientImpl implements WKSClientService {
      * @see com.openexchange.guard.wksclient.WKSClientService#findAll(java.lang.String, int)
      */
     @Override
-    public Collection<WKSResult> findAll(String email, int timeout) throws OXException {
-        return findAll(email, timeout, getHostFromEmail(email), TLS_PORT);
+    public Collection<WKSResult> findAll(String email, int userId, int cid, int timeout) throws OXException {
+        return findAll(email, userId, cid, timeout, getHostFromEmail(email), TLS_PORT);
     }
 
     /* (non-Javadoc)
      * @see com.openexchange.guard.wksclient.WKSClientService#findAll(java.lang.String, int, java.lang.String, int)
      */
     @Override
-    public Collection<WKSResult> findAll(String email, int timeout, String host, int port) throws OXException {
+    public Collection<WKSResult> findAll(String email, int userId, int cid, int timeout, String host, int port) throws OXException {
         final String verifiedEmail = new EmailValidator().assertInput(email);
         String emailUserHash = CipherUtil.getEmailUserHash(verifiedEmail);
         if (emailUserHash != null && !emailUserHash.isEmpty()) {
@@ -112,16 +112,16 @@ public class WKSClientImpl implements WKSClientService {
      * @see com.openexchange.guard.wksclient.WKSClientService#find(java.lang.String, int)
      */
     @Override
-    public Optional<WKSResult> find(String email, int timeout) throws OXException {
-        return find(email, timeout, getHostFromEmail(email),TLS_PORT);
+    public Optional<WKSResult> find(String email, int userId, int cid, int timeout) throws OXException {
+        return find(email, userId, cid, timeout, getHostFromEmail(email), TLS_PORT);
     }
 
     /* (non-Javadoc)
      * @see com.openexchange.guard.wksclient.WKSClientService#find(java.lang.String, int, java.lang.String, int)
      */
     @Override
-    public Optional<WKSResult> find(String email, int timeout, String host, int port) throws OXException {
-        Collection<WKSResult> results = findAll(email, timeout, host, port);
+    public Optional<WKSResult> find(String email, int userId, int cid, int timeout, String host, int port) throws OXException {
+        Collection<WKSResult> results = findAll(email, userId, cid, timeout, host, port);
         //Do not return required or revoked keys and filter keys which do not contain the email (See WKS-RFC 3.1)
 
         Optional<WKSResult> key = results.stream().filter(r ->
