@@ -128,4 +128,13 @@ public interface GuardMaintenanceService {
      */
     void changeUser (String email, String newEmail) throws OXException;
 
+    /**
+     * Creates new master keys and returns index
+     * createMasterKeys
+     *
+     * @return The index of the created master key
+     * @throws OXException
+     */
+    int createMasterKeys() throws OXException;
+
 }
