@@ -101,7 +101,14 @@ public class AuthUtils {
      * @throws OXException
      */
     public static UserIdentity getUserIdentityFrom(GuardUserSession guardUserSession) throws OXException {
-        return getUserIdentityFrom(guardUserSession.getGuardUserId(), guardUserSession.getGuardContextId());
+        return getUserIdentityFrom(guardUserSession.getGuardUserId(),
+            guardUserSession.getGuardContextId(),
+            guardUserSession.getUserId(),
+            guardUserSession.getContextId());
+    }
+
+    public static UserIdentity getUserIdentityFrom(int guardUserId, int guardContextId) throws OXException {
+        return getUserIdentityFrom(guardUserId, guardContextId, 0, 0);
     }
 
     /**
@@ -112,7 +119,7 @@ public class AuthUtils {
      * @return The {@link UserIdentity} from the given ids.
      * @throws OXException
      */
-    public static UserIdentity getUserIdentityFrom(int guardUserId, int guardContextId) throws OXException {
+    public static UserIdentity getUserIdentityFrom(int guardUserId, int guardContextId, int oxUserId, int oxCid) throws OXException {
         //new user identity
         UserIdentity userIdentity = new UserIdentity(null);
 
@@ -120,15 +127,11 @@ public class AuthUtils {
         OXGuardUser oxGuardUser = new OXGuardUser( guardUserId, guardContextId);
         userIdentity.setOXGuardUser(oxGuardUser);
 
-        //get OX appsuite user information and add them
+        //get OX appsuite user information if guest key info was passed or absent and add them
         OXUserService userService = Services.getService(OXUserService.class);
         //..get it by guard-id and guard-cid
-        OXUser oxUser = userService.getUser(guardContextId, guardUserId);
-        //..we only use oxUser's email and name and have to adjust the userid and cid, because it can be possible that
-        // multiple guests user exists with the same email address
+        OXUser oxUser = (oxUserId == 0 || oxCid < 0) ? userService.getUser(guardContextId, guardUserId) : new OXUser(null, oxUserId, oxCid, null, false, null);
         if (oxUser != null) {
-            oxUser.setContextId(guardContextId);
-            oxUser.setUserId(guardUserId);
             userIdentity.setOXUser(oxUser);
             userIdentity.setIdentity(oxUser.getEmail());
         }
@@ -145,12 +148,14 @@ public class AuthUtils {
      * @param email
      * @return
      */
-    public static JsonObject createAuthJson (int userid, int cid, String email, String authenticationFieldName, String authenticationFieldValue, String language) {
+    public static JsonObject createAuthJson(int userid, int cid, int oxUserId, int oxCid, String email, String authenticationFieldName, String authenticationFieldValue, String language) {
         JsonObject auth = new JsonObject();
         auth.addProperty(authenticationFieldName, authenticationFieldValue);
         auth.addProperty("email", email);
         auth.addProperty("user_id", userid);
         auth.addProperty("cid", cid);
+        auth.addProperty("oxUserId", oxUserId);
+        auth.addProperty("oxCid", oxCid);
         auth.addProperty("language", language);
         return (auth);
     }
