@@ -103,7 +103,7 @@ public class GuestLoginHandler {
      * @throws OXException
      */
     public void guestlogin(HttpServletRequest request, HttpServletResponse response) throws OXException {
-        JsonObject login_json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
+        JsonObject login_json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request, 0, 0);
         response.setContentType("application/json");
         // response.addHeader("Access-Control-Allow-Origin", "*");
         response.setStatus(HttpServletResponse.SC_OK);
@@ -218,6 +218,8 @@ public class GuestLoginHandler {
                                     AuthUtils.createAuthJson(
                                         keys.getUserid(),
                                         keys.getContextid(),
+                                    0,
+                                    0,
                                         keys.getEmail(),
                                         ENCR_PASSWORD_AUTH_FIELD_NAME,
                                         json.has("encr_password") ? json.get("encr_password").getAsString() : "",
@@ -237,6 +239,8 @@ public class GuestLoginHandler {
                             AuthUtils.createAuthJson(
                                 keys.getUserid(),
                                 keys.getContextid(),
+                            0,
+                            0,
                                 keys.getEmail(),
                                 ENCR_PASSWORD_AUTH_FIELD_NAME,
                                 json.has("encr_password") ? json.get("encr_password").getAsString() : "",
