@@ -49,14 +49,15 @@
 
 package com.openexchange.guard.auth;
 
-import java.io.IOException;
+import static com.openexchange.java.Autoboxing.B;
+import static com.openexchange.java.Autoboxing.I;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Map.Entry;
-import java.util.concurrent.atomic.AtomicReference;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import org.apache.commons.codec.binary.Base64;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.gson.JsonObject;
@@ -78,8 +79,10 @@ import com.openexchange.guard.handler.ResponseHandler;
 import com.openexchange.guard.inputvalidation.EmailValidator;
 import com.openexchange.guard.internal.GuardVersion;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.MasterKey;
 import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.OxCookie;
@@ -106,8 +109,6 @@ public class LoginHandler {
     private final static String ENCR_PASSWORD_AUTH_FIELD_NAME = "encr_password";
     private final static String PGP_SESSION_KEY_AUTH_FIELD_NAME = "pgp_session_key";
 
-    private AtomicReference<String> pubkey = null;
-
     //Other values than the actual auth-token which can be returned in the "auth" response field
     private static String AUTH_RET_LOCKOUT = "Lockout";
     private static String AUTH_RET_UPDATING = "Updating";
@@ -115,9 +116,9 @@ public class LoginHandler {
     private static String AUTH_RET_PASSWORD_NEEDED = "Password Needed";
     private static String AUTH_RET_ERROR = "Error: Problem with login";
 
-    public void login(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession, OxCookie cookie) throws IOException {
+    public void login(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession, OxCookie cookie) {
         try {
-            JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
+            JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request, userSession.getUserId(), userSession.getContextId());
             GuardCapabilities settings = Services.getService(OXUserService.class).getGuardCapabilieties(userSession.getContextId(), userSession.getUserId());
             login(json, request, response, userSession, cookie, settings);
         } catch (Exception ex) {
@@ -134,21 +135,21 @@ public class LoginHandler {
         // response.addHeader("Access-Control-Allow-Origin", "*");
         response.setStatus(HttpServletResponse.SC_OK);
         response.addHeader("Connection", "close");
-        int userid = userSession.getGuardUserId();
-        int cid = userSession.getGuardContextId();
+        int userid = userSession.getUserId();
+        int cid = userSession.getContextId();
         String lang = JsonUtil.getStringFromJson(json, "lang");
         JsonObject returnJson = new JsonObject();
         returnJson.add("lang", getAvailableLanguagesJson(lang));
         GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
         returnJson.addProperty("server", GuardVersion.getGuardVersion());
         // Get public RSA keys for password encryption
-        String pubkey = getPublicKey();
+        JsonObject pubkey = getPublicKey(userid, cid);
         if (pubkey != null) {
-            returnJson.addProperty("pubKey", pubkey);
+            returnJson.add("pubKey", pubkey);
         }
         try {
             GuardKeyService keyService = Services.getService(GuardKeyService.class);
-            String email = ((json == null) || (json.get("email") == null) || json.get("email").isJsonNull()) ? null : json.get("email").getAsString();
+            String email = ((json == null) || (json.get("email") == null) || json.get("email").isJsonNull() || json.get("email").getAsString().isEmpty()) ? null : json.get("email").getAsString();
             if(email != null) {
                 email = new EmailValidator().assertInput(email, "email");
             }
@@ -176,24 +177,23 @@ public class LoginHandler {
                     ServletUtils.sendJsonOK(response, returnJson);
                     LOG.debug("The server is currently down for maintenance. cid = " + cid + " userid = " + userid);
                     return;
-                } else {
-                    throw ex;
                 }
+                throw ex;
             }
 
-            returnJson.addProperty("cid", cid);
-            returnJson.addProperty("userid", userid);
+            returnJson.addProperty("cid", I(userSession.getGuardContextId()));
+            returnJson.addProperty("userid", I(userSession.getGuardUserId()));
             GuardKeys keys = null;
             String keyid = ServletUtils.getStringParameter(request, "keyid");
             if (keyid != null) {
                 try {
-                    Long kid = Long.parseLong(keyid);
-                    keys = keyService.getKeys(userid, cid, kid);
+                    long kid = Long.parseLong(keyid);
+                    keys = keyService.getKeys(userSession.getGuardUserId(), userSession.getGuardContextId(), kid);
                 } catch (Exception ex) {
                     LOG.error("Problem with login for Key ID " + keyid, ex);
                 }
             } else {
-                keys = keyService.getKeys(userid, cid);
+                keys = keyService.getKeys(userSession.getGuardUserId(), userSession.getGuardContextId());
             }
 
             if (keys == null) {
@@ -232,19 +232,19 @@ public class LoginHandler {
 
             returnJson.addProperty("primaryEmail", keys.getEmail());
             returnJson.add("settings", AuthUtils.getSettings(keys.getSettings().toString(), settings, userid, cid));
-            returnJson.add("recoveryAvail", new JsonPrimitive(keys.isRecoveryAvail()));
+            returnJson.add("recoveryAvail", new JsonPrimitive(B(keys.isRecoveryAvail())));
             // Check for initial setup, not ready for authentication
             boolean proceed = true;
             if (keys.isPasswordNeeded() == true) {
                 returnJson.addProperty("auth", AUTH_RET_PASSWORD_NEEDED);
                 if ((keys.getQuestion() == null) && (keys.isRecoveryAvail())) {  // New, first time use
-                    returnJson.addProperty("new", true);
+                    returnJson.addProperty("new", Boolean.TRUE);
                 }
                 proceed = false;
             }
             SecondFactorService secondFactor = Services.getService(SecondFactorService.class);
-            if (secondFactor.hasSecondFactor(keys.getUserid(), keys.getContextid())) {
-                returnJson.addProperty("pin", true);
+            if (secondFactor.hasSecondFactor(userSession.getUserId(), userSession.getContextId(), keys.getUserid(), keys.getContextid())) {
+                returnJson.addProperty("pin", Boolean.TRUE);
                 proceed = false;
             }
 
@@ -261,7 +261,7 @@ public class LoginHandler {
 
                 if (encrpass.length() > 1) {// If provided with encryption password, check
                     try {
-                        VerificationResult passwordVerification = verifyPassword(keys, userid, cid, encrpass, request);
+                        VerificationResult passwordVerification = verifyPassword(keys, userid, cid, encrpass);
                         if (passwordVerification.isValidated()) {
                             GuardKeysUpdater updater = Services.getService(GuardKeysUpdater.class);
                             if (updater != null) {
@@ -271,6 +271,8 @@ public class LoginHandler {
                                     AuthUtils.createAuthJson(
                                         keys.getUserid(),
                                         keys.getContextid(),
+                                    userSession.getUserId(),
+                                    userSession.getContextId(),
                                         keys.getEmail(),
                                         ENCR_PASSWORD_AUTH_FIELD_NAME,
                                         (json != null && json.has("encr_password")) ? json.get("encr_password").getAsString() : "",
@@ -302,6 +304,8 @@ public class LoginHandler {
                             AuthUtils.createAuthJson(
                                 keys.getUserid(),
                                 keys.getContextid(),
+                                userSession.getUserId(),
+                                userSession.getContextId(),
                                 keys.getEmail(),
                                 PGP_SESSION_KEY_AUTH_FIELD_NAME,
                                 pgpSessionPassword,
@@ -372,7 +376,7 @@ public class LoginHandler {
      * @return
      * @throws Exception
      */
-    private VerificationResult verifyPassword(GuardKeys key, int userid, int cid, String password, HttpServletRequest request) throws Exception {
+    private VerificationResult verifyPassword(GuardKeys key, int userid, int cid, String password) throws Exception {
 
         if (key.getPGPSecretKeyRing() != null && PGPUtil.verifyPassword(key.getPGPSecretKeyRing(), password, key.getSalt())) {
             return (new VerificationResult(key, true));
@@ -416,31 +420,23 @@ public class LoginHandler {
     }
 
     /**
-     * Loads the public key used for client encryption
-     */
-    private void loadPublic() {
-        GuardKeys passwordKeys;
-        try {
-            GuardKeyService keyService = Services.getService(GuardKeyService.class);
-            passwordKeys = keyService.getKeys(-2, 0);
-            if (passwordKeys != null) {
-                pubkey = new AtomicReference<String>();
-                pubkey.set(passwordKeys.getEncodedPublic());
-            }
-        } catch (Exception e) {
-            LOG.error("Error getting public RSA key ", e);
-        }
-    }
-
-    /**
-     * Get the public key.  If not loaded, load from database
+     * Get the public key. If not loaded, load from database
+     *
      * @return
+     * @throws OXException
      */
-    private String getPublicKey() {
-        if (pubkey == null) {
-            loadPublic();
+    private static JsonObject getPublicKey(int userId, int cid) {
+        try {
+            MasterKeyService masterKeys = Services.getService(MasterKeyService.class);
+            MasterKey mKey = masterKeys.getMasterKey(userId, cid);
+            JsonObject pubKey = new JsonObject();
+            pubKey.addProperty("index", I(mKey.getIndex()));
+            pubKey.addProperty("key", Base64.encodeBase64String(mKey.getClientPublic().getEncoded()));
+            return pubKey;
+        } catch (OXException ex) {
+            LOG.error("Unable to retrieve public key for user", ex);
         }
-        return (pubkey == null ? null : pubkey.get());
+        return null;
     }
 
     /**
