@@ -49,7 +49,6 @@
 
 package com.openexchange.guard.auth;
 
-import java.util.List;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.json.JSONObject;
@@ -58,20 +57,16 @@ import org.slf4j.LoggerFactory;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
-import com.openexchange.guard.cipher.GuardCipherAlgorithm;
-import com.openexchange.guard.cipher.GuardCipherFactoryService;
-import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.common.util.JsonUtil;
-import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.handler.ResponseHandler;
 import com.openexchange.guard.inputvalidation.EmailValidator;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
-import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
@@ -96,7 +91,7 @@ public class SecondaryEmailHandler {
      * @throws Exception
      */
     public void changeSecondaryEmail(HttpServletRequest request, HttpServletResponse response, int userId, int cid, OxCookie cookie) throws Exception {
-        JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
+        JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request, userId, cid);
         GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
         Api ap = new Api(cookie, request);
         if (ap.verifyLogin() == false) {// verify logged into UI
@@ -137,17 +132,13 @@ public class SecondaryEmailHandler {
 
     public String getSecondaryEmail(int userid, int cid) throws Exception {
         KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
-        List<GuardKeys> userKeys = ogKeyTableStorage.getKeysForUser(userid, cid);
-        if (userKeys.size() > 0) {
-            String encr_answer = userKeys.get(0).getAnswer();
-            if (encr_answer == null) {
-                return null;
-            }
-            GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
-            String rc = Services.getService(GuardMasterKeyService.class).getMasterKey().getRC();
-            return cipherService.decrypt(encr_answer, rc, "e");
+        GuardKeys userKeys = ogKeyTableStorage.getCurrentKeyForUser(userid, cid);
+        String encr_answer = userKeys.getAnswer();
+        if (encr_answer == null) {
+            return null;
         }
-        return null;
+        return Services.getService(MasterKeyService.class).getRcDecrypted(encr_answer, "e", userKeys.getMasterKeyIndex());
+
     }
 
     private boolean updateEmail(int userid, int cid, String email) throws OXException {
