@@ -53,7 +53,7 @@ public class FileTyper {
 
     /**
      * Gets type from filename. If not found, return applicaiton/octet
-     * 
+     *
      * @param filename
      * @return
      */
@@ -64,7 +64,7 @@ public class FileTyper {
     /**
      * Gets the filetype from the filename.
      * If not found, returns default
-     * 
+     *
      * @param filename
      * @param def
      * @return
@@ -85,6 +85,10 @@ public class FileTyper {
                         return ("image/png");
                     case "bmp":
                         return ("image/bmp");
+                    case "heic":
+                        return ("image/heic");
+                    case "heif":
+                        return ("image/heif");
 
                     // audio
                     case "wav":
