@@ -63,7 +63,7 @@ import com.openexchange.osgi.annotation.SingletonService;
 @SingletonService
 public interface ResponseHandler {
 
-    JsonObject getJsonAndDecodeEncryptedPasswords(HttpServletRequest request) throws OXException;
-    
+    JsonObject getJsonAndDecodeEncryptedPasswords(HttpServletRequest request, int userId, int cid) throws OXException;
+
     JsonObject getJson(HttpServletRequest request) throws OXException;
 }
