@@ -50,6 +50,7 @@
 package com.openexchange.guard.handler.impl;
 
 import java.io.BufferedReader;
+import java.security.Key;
 import javax.servlet.http.HttpServletRequest;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -61,7 +62,8 @@ import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.common.util.JsonUtil;
 import com.openexchange.guard.handler.ResponseHandler;
 import com.openexchange.guard.handler.exceptions.GuardResponseHandlerExceptionCodes;
-import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
+import com.openexchange.server.ServiceLookup;
 
 /**
  * {@link ResponseHandlerImpl}
@@ -72,17 +74,15 @@ import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 public class ResponseHandlerImpl implements ResponseHandler {
 
     private static final Logger LOG = LoggerFactory.getLogger(ResponseHandlerImpl.class);
-    private final GuardMasterKeyService masterKeyService;
-    private final GuardCipherFactoryService cipherFactoryService;
+    private ServiceLookup services;
 
-    public ResponseHandlerImpl(GuardMasterKeyService masterKeyService, GuardCipherFactoryService cipherFactoryService) {
-        this.masterKeyService = masterKeyService;
-        this.cipherFactoryService = cipherFactoryService;
+    public ResponseHandlerImpl(ServiceLookup services) {
+        this.services = services;
     }
 
      @Override
-    public JsonObject getJsonAndDecodeEncryptedPasswords(HttpServletRequest request) throws OXException {
-        return decodeEncryptedPassword(getJson(request));
+     public JsonObject getJsonAndDecodeEncryptedPasswords(HttpServletRequest request, int userId, int cid) throws OXException {
+         return decodeEncryptedPassword(getJson(request), userId, cid);
     }
 
     @Override
@@ -126,20 +126,23 @@ public class ResponseHandlerImpl implements ResponseHandler {
      * @return
      * @throws OXException
      */
-    private JsonObject decodeEncryptedPassword(JsonObject result) throws OXException {
+    private JsonObject decodeEncryptedPassword(JsonObject result, int userId, int cid) throws OXException {
         if (result == null) {
             return (null);
         }
-        result = decr(result, "e_password", "password");
-        result = decr(result, "e_encr_password", "encr_password");
+        result = decr(result, "e_password", "password", userId, cid);
+        result = decr(result, "e_encr_password", "encr_password", userId, cid);
         return result;
     }
 
-    private JsonObject decr(JsonObject result, String key, String newkey) throws OXException {
+    private JsonObject decr(JsonObject result, String key, String newkey, int userId, int cid) throws OXException {
         if (result.has(key)) {
             String encr = result.get(key).getAsString();
-            GuardCipherService cipherService = this.cipherFactoryService.getCipherService(GuardCipherAlgorithm.RSA);
-            String decoded = cipherService.decrypt(encr, masterKeyService.getMasterKey().getPrivateKey());
+            GuardCipherFactoryService cipherFactoryService = services.getServiceSafe(GuardCipherFactoryService.class);
+            MasterKeyService mKeyService = services.getOptionalService(MasterKeyService.class);
+            GuardCipherService cipherService = cipherFactoryService.getCipherService(GuardCipherAlgorithm.RSA);
+            Key decrKey = mKeyService.getDecryptedClientKey(mKeyService.getMasterKey(userId, cid, false));
+            String decoded = cipherService.decrypt(encr, decrKey);
             if (decoded != null) {
                 result.addProperty(newkey, decoded);
             } else {
