@@ -68,6 +68,8 @@ public enum GuardMaintenanceExceptionCodes implements DisplayableOXExceptionCode
     FAILED_UPGRADING_TO_OX_ACCOUNT("Failed upgrading to OX account for e-mail '%1$s'", GuardMaintenanceExceptionMessages.FAILED_UPGRADING_TO_OX_ACCOUNT, CATEGORY_ERROR, 2),
     /** Unable to resolve the e-mail address '%1$s' to a local user. */
     UNABLE_TO_RESOLVE_MAIL_ADDRESS("Unable to resolve the e-mail address '%1$s' to a local user.", GuardMaintenanceExceptionMessages.UNABLE_TO_RESOLVE_MAIL_ADDRESS, CATEGORY_ERROR, 3),
+    /** Account not found */
+    ACCOUNT_NOT_FOUND("Unable to find account for e-mail address '%1$s'", CATEGORY_ERROR, 4),
 
     ;
 
