@@ -61,11 +61,13 @@ import com.openexchange.guard.databaseChecker.GuardDatabaseRepair;
 import com.openexchange.guard.email.storage.ogEmail.Email;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
+import com.openexchange.guard.guest.GuestLookupService;
 import com.openexchange.guard.guestreset.GuestResetService;
 import com.openexchange.guard.guestupgrade.GuestUpgradeService;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.ImportSystemPublicKey;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.osgi.Services;
@@ -144,16 +146,19 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
             }
             if (keys.getContextid() < 0) {// Guest
                 int templid = 0;
+                GuestLookupService guestService = Services.getService(GuestLookupService.class);
+                int userId = guestService.lookupOxUserId(email, keys.getContextid());
+                int cid = keys.getContextid() * -1;
                 try {
                     GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
-                    templid = guardConfigService.getIntProperty(GuardProperty.templateID, keys.getUserid(), keys.getContextid());
+                    templid = guardConfigService.getIntProperty(GuardProperty.templateID, userId, cid);
                 } catch (Exception e) {
                     LOG.error("problem getting template id for reset password email");
                 }
                 GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-                String defaultLanguage = configService.getProperty(GuardProperty.defaultLanguage);
+                String defaultLanguage = configService.getProperty(GuardProperty.defaultLanguage, userId, cid);
 
-                reset(email, keyService, keys, templid, defaultLanguage);
+                reset(email, keyService, userId, cid, keys, templid, defaultLanguage);
                 LOG.info("Reset sent for email {}", email);
             } else {
                 GuardUserSession userSession = new GuardUserSession(null, null, keys.getContextid(), keys.getUserid(), false, null, null);
@@ -165,19 +170,19 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
         }
     }
 
-    protected void reset(String email, GuardKeyService keyService, GuardKeys keys, int templid, String defaultLanguage) throws OXException {
+    protected void reset(String email, GuardKeyService keyService, int userId, int cid, GuardKeys keys, int templid, String defaultLanguage) throws OXException {
         boolean recoveryEnabled = keyService.isRecoveryEnabled(keys.getUserid(), keys.getContextid());
         if (!recoveryEnabled) {
             LOG.info("Failed to reset password for email address {} as recovery is not enabled/available.", email);
             throw GuardCoreExceptionCodes.DISABLED_ERROR.create("reset password");
         }
 
-        String newpass = keyService.generatePassword(keys.getUserid(), keys.getContextid());
+        String newpass = keyService.generatePassword(userId, cid);
         MailCreatorService mailCreatorService = Services.getService(MailCreatorService.class);
-        JsonObject mail = mailCreatorService.getResetEmail(email, mailCreatorService.getFromAddress(email, email, keys.getUserid(), keys.getContextid()), newpass, defaultLanguage, templid, "", 0, 0);
+        JsonObject mail = mailCreatorService.getResetEmail(email, mailCreatorService.getFromAddress(email, email, userId, cid), newpass, defaultLanguage, templid, "", 0, 0);
 
         GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
-        guardNotificationService.send(mail, keys.getUserid(), keys.getContextid(), null);
+        guardNotificationService.send(mail, userId, cid, null);
 
         keyService.resetPassword(email, newpass);
     }
@@ -262,4 +267,10 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
 
     }
 
+    @Override
+    public int createMasterKeys() throws OXException {
+        final MasterKeyService masterKeyService = Services.getService(MasterKeyService.class);
+        return masterKeyService.createKey().getIndex();
+    }
+
 }
