@@ -93,11 +93,11 @@ import com.openexchange.guard.internal.GuardVersion;
 import com.openexchange.guard.keymanagement.services.AccountCreationService;
 import com.openexchange.guard.keymanagement.services.ContactKeyService;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
-import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.keymanagement.services.ImportSystemPublicKey;
 import com.openexchange.guard.keymanagement.services.KeyCreationService;
 import com.openexchange.guard.keymanagement.services.KeyImportService;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
 import com.openexchange.guard.keymanagement.services.PasswordChangeService;
 import com.openexchange.guard.keymanagement.services.PublicExternalKeyService;
 import com.openexchange.guard.keymanagement.services.RecipKeyService;
@@ -156,7 +156,7 @@ public class GuardServiceActivator extends HousekeepingActivator {
     @Override
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] { HttpService.class, SignalHttpApiAvailabilityService.class,
-            GuardConfigurationService.class, GuardMasterKeyService.class, TimerService.class, GuardTranslationService.class,
+            GuardConfigurationService.class, MasterKeyService.class, TimerService.class, GuardTranslationService.class,
             GuardRatifierService.class, GuardCipherFactoryService.class, GuardDatabaseService.class, GuardSessionService.class,
             KeyCacheStorage.class, RecipKeyService.class, MailCreatorService.class, DNSService.class, GlobalSettingsStorage.class,
             GuardNotificationService.class, GuardAntiAbuseService.class, GuardKeyService.class, EmailStorage.class,
@@ -195,7 +195,7 @@ public class GuardServiceActivator extends HousekeepingActivator {
         trackService(GuardMaintenanceService.class);
 
         trackService(HttpConnectionPoolService.class);
-        registerService(ResponseHandler.class, new ResponseHandlerImpl(getService(GuardMasterKeyService.class), getService(GuardCipherFactoryService.class)));
+        registerService(ResponseHandler.class, new ResponseHandlerImpl(this));
         trackService(ResponseHandler.class);
 
         openTrackers();
@@ -210,7 +210,7 @@ public class GuardServiceActivator extends HousekeepingActivator {
             PopulateKeyCacheTask populateKeyCacheTask = new PopulateKeyCacheTask(guardConfigurationService,
                 getService(KeyCacheStorage.class),
                 AES_CBC,
-                getService(GuardMasterKeyService.class));
+                getService(MasterKeyService.class));
             TimerService timerService = getService(TimerService.class);
             this.scheduledKeyCacheTask = timerService.scheduleAtFixedRate(populateKeyCacheTask,
                 0,
@@ -256,8 +256,6 @@ public class GuardServiceActivator extends HousekeepingActivator {
             dailyJobScheduler.unregisterAll();
         }
 
-        unregisterService(GuardMasterKeyService.class);
-
         //Unregistering the OX Guard servlets
         GuardServlets.unregisterServlets(getService(HttpService.class));
         super.stopBundle();
