@@ -60,7 +60,6 @@ import com.openexchange.antiabuse.AllowParameters;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.auth.AuthUtils;
-import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
@@ -70,7 +69,6 @@ import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseWrapper;
 import com.openexchange.guard.keymanagement.commons.antiabuse.KeyAntiAbuseWrapper;
 import com.openexchange.guard.keymanagement.commons.antiabuse.UserAntiAbuseWrapper;
-import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.logging.GuardLogProperties;
 import com.openexchange.guard.logging.LoggingHelper;
 import com.openexchange.guard.osgi.Services;
@@ -166,7 +164,7 @@ public abstract class GuardServletAction {
 
     /**
      * Gets the {@link GuardErrorResponseRenderer} which should be used to render exceptions for clients.
-     * 
+     *
      * @return The {@link GuardErrorResponseRenderer} which should be used for exception handling.
      */
     public GuardErrorResponseRenderer getErrorResponseRenderer() {
@@ -248,7 +246,6 @@ public abstract class GuardServletAction {
             }
             ServletUtils.sendResponse(response, HttpServletResponse.SC_UNAUTHORIZED, "Unauthorized");
         }
-        cleanup(request);
     }
 
     /**
@@ -355,10 +352,8 @@ public abstract class GuardServletAction {
      * @return The parsed {@link UserIdentity}, or null if the request did not contain enough information for creating a {@link UserIdentity} object.
      * @throws OXException
      */
-    protected UserIdentity getUserIdentityFrom(HttpServletRequest request) throws OXException {
-        return new UserIdentityParameterParser(Services.getService(GuardMasterKeyService.class),
-            Services.getService(GuardCipherFactoryService.class),
-            request).parse();
+    protected UserIdentity getUserIdentityFrom(HttpServletRequest request, int userId, int cid) throws OXException {
+        return new UserIdentityParameterParser(request).parse(userId, cid);
     }
 
     /**
@@ -368,8 +363,8 @@ public abstract class GuardServletAction {
      * @return The parsed {@link UserIdentity}
      * @throws OXException
      */
-    protected UserIdentity requireUserIdentityFrom(HttpServletRequest request) throws OXException {
-        final UserIdentity userIdentity = getUserIdentityFrom(request);
+    protected UserIdentity requireUserIdentityFrom(HttpServletRequest request, int userId, int cid) throws OXException {
+        final UserIdentity userIdentity = getUserIdentityFrom(request, userId, cid);
         final boolean require = true;
         return requireOrReturn(userIdentity, require);
     }
