@@ -71,6 +71,7 @@ import com.openexchange.guard.servlets.pgpcore.PGPCoreServlet;
 import com.openexchange.guard.servlets.pgpmail.PGPMailServlet;
 import com.openexchange.guard.servlets.ping.PingServlet;
 import com.openexchange.guard.servlets.supportApi.SupportServlet;
+import com.openexchange.server.ServiceLookup;
 
 /**
  * Handles registration and de-registration of OX Guard servlets
@@ -103,8 +104,10 @@ public class GuardServlets {
      * @throws ServletException
      * @throws OXException
      */
-    public static void registerServlets(HttpService httpService, GuardConfigurationService configService) throws ServletException, NamespaceException, OXException {
+    public static void registerServlets(ServiceLookup services) throws ServletException, NamespaceException, OXException {
 
+        HttpService httpService = services.getServiceSafe(HttpService.class);
+        GuardConfigurationService configService = services.getServiceSafe(GuardConfigurationService.class);
         // Create authentication handlers
         // Rest API Authentication
         String restApiUsername = configService.getProperty(GuardProperty.restApiUsername);
@@ -121,7 +124,7 @@ public class GuardServlets {
         httpService.registerServlet(GUARD_PING_SERVLET_PATH, new PingServlet(), null, null);
         httpService.registerServlet(GUARD_KEY_MANAGEMENT_SERVLET_PATH, new KeymanagementServlet(), null, null);
         httpService.registerServlet(GUARD_PGP_CORE_SERVLET_PATH, new PGPCoreServlet(), null, null);
-        httpService.registerServlet(GUARD_PGPMAIL_SERVLET_PATH, new PGPMailServlet(), null, null);
+        httpService.registerServlet(GUARD_PGPMAIL_SERVLET_PATH, new PGPMailServlet(services), null, null);
         httpService.registerServlet(GUARD_MAIL_SERVLET_PATH, new MailServlet(), null, null);
         httpService.registerServlet(GUARD_LOGIN_SERVLET_PATH, new LoginServlet(basicRestAuthServletAuthentication), null, null);
         httpService.registerServlet(GUARD_GUEST_SERVLET_PATH, new GuestServlet(), null, null);
