@@ -52,11 +52,14 @@ package com.openexchange.guard.servlets.authentication;
 import javax.servlet.http.HttpServletRequest;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.cipher.GuardCipherAlgorithm;
+import com.openexchange.guard.cipher.GuardCipherFactoryService;
+import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.internal.UserData;
-import com.openexchange.guard.oxapi.OxCookie;
-import com.openexchange.guard.pgp.PGPUtils;
+import com.openexchange.guard.osgi.Services;
+import com.openexchange.guard.session.GuardSessionService;
 
 /**
  * {@link AuthenticationDataExtractor}
@@ -71,6 +74,13 @@ public class AuthenticationDataExtractor {
     private static final String PARAM_AUTH_TOKEN = "auth";
     private static final String PARAM_PLAIN_TEXT_PASSWORD = "password";
 
+    private static String decodeEPass(String epass, String sessionId) throws OXException {
+        GuardSessionService sessionService = Services.getService(GuardSessionService.class);
+        String token = sessionService.getToken(sessionId);
+        GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
+        return (cipherService.decrypt(epass, token));
+    }
+
     private String getPassword(String authToken, String epassword, String password, GuardUserSession userSession) throws OXException {
         //Try to parse the RSA encrypted authentication structure
         if (authToken != null) {
@@ -86,7 +96,7 @@ public class AuthenticationDataExtractor {
         if (epassword != null && !epassword.isEmpty()) {
             String sessionId = userSession.getGuardSession();
             if(sessionId != null && !sessionId.isEmpty()) {
-                return PGPUtils.decodeEPass(epassword, sessionId);
+                return decodeEPass(epassword, sessionId);
             }
         }
 
