@@ -56,9 +56,14 @@ import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
-import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
+import com.openexchange.guard.handler.exceptions.GuardResponseHandlerExceptionCodes;
+import com.openexchange.guard.keymanagement.commons.MasterKey;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
+import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.user.UserIdentity;
 
+import static com.openexchange.java.Autoboxing.i;
+
 /**
  * {@link UserIdentityParameterParser}
  *
@@ -69,41 +74,52 @@ public class UserIdentityParameterParser implements UserIdentityParser {
 
     private static final String PARAM_PASSWORD = "password";
     private static final String PARAM_E_PASSWORD = "e_password";
+    private static final String PARAM_KEY_INDEX = "keyIndex";
 
     private final HttpServletRequest request;
-    private GuardCipherFactoryService cipherFactoryService;
-    private GuardMasterKeyService masterKeyService;
 
     /**
      * Initializes a new {@link UserIdentityParameterParser}.
      * @param request The request to parse the {@link UserIdentity} from
      */
-    public UserIdentityParameterParser(GuardMasterKeyService masterKeyService, GuardCipherFactoryService cipherFactoryService, HttpServletRequest request) {
-        this.masterKeyService = Objects.requireNonNull(masterKeyService, "masterKeyService must not be null");
-        this.cipherFactoryService = Objects.requireNonNull(cipherFactoryService, "cipherFactoryService msut not be null");
-        this.request = Objects.requireNonNull(request, "request must not be null");
+    public UserIdentityParameterParser(HttpServletRequest request) {
+        this.request = request;
     }
 
-    private String decryptPassword(String e_password) throws OXException {
-        GuardCipherService cipherService = this.cipherFactoryService.getCipherService(GuardCipherAlgorithm.RSA);
-        return cipherService.decrypt(e_password, masterKeyService.getMasterKey().getPrivateKey());
+    private String decryptPassword(String e_password, Integer index, int userId, int cid) throws OXException {
+        GuardCipherFactoryService cipherFactoryService = Objects.requireNonNull(Services.getService(GuardCipherFactoryService.class));
+        GuardCipherService cipherService = cipherFactoryService.getCipherService(GuardCipherAlgorithm.RSA);
+        MasterKeyService masterKeyService = Objects.requireNonNull(Services.getService(MasterKeyService.class));
+        MasterKey mkey;
+        if (index != null) {
+            mkey = masterKeyService.getMasterKey(i(index), false);
+        } else {
+            mkey = masterKeyService.getMasterKey(userId, cid, false);
+        }
+        return cipherService.decrypt(e_password, masterKeyService.getDecryptedClientKey(mkey));
     }
 
-    private String parsePassword() throws OXException {
+    private String parsePassword(int userId, int cid) throws OXException {
         String password = request.getParameter(PARAM_PASSWORD);
         if(password != null) {
             return password;
         }
 
         String e_password = request.getParameter(PARAM_E_PASSWORD);
-        if(e_password != null) {
-            String decryptedPassword = decryptPassword(e_password);
-            if(decryptedPassword == null) {
-               throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
+        if (e_password != null) {
+            Integer index = null;
+            if (request.getParameter(PARAM_KEY_INDEX) != null) {
+                try {
+                    index = Integer.valueOf(request.getParameter(PARAM_KEY_INDEX));
+                } catch (@SuppressWarnings("unused") NumberFormatException e) {
+                    throw GuardResponseHandlerExceptionCodes.BAD_RSA_ERROR.create();
+                }
             }
-            else {
-                return decryptedPassword;
+            String decryptedPassword = decryptPassword(e_password, index, userId, cid);
+            if (decryptedPassword == null) {
+                throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
             }
+            return decryptedPassword;
         }
         return null;
     }
@@ -113,13 +129,18 @@ public class UserIdentityParameterParser implements UserIdentityParser {
      * @see com.openexchange.guard.servlets.authentication.UserIdentityParser#parse()
      */
     @Override
-    public UserIdentity parse() throws OXException {
+    public UserIdentity parse(int userId, int cid) throws OXException {
         if(request.getParameterMap().size() > 0) {
-            String password = parsePassword();
+            String password = parsePassword(userId, cid);
             if(password != null) {
                 return new UserIdentity(/*TODO*/null, password);
             }
         }
         return null;
     }
+
+    @Override
+    public UserIdentity parse() throws OXException {
+        throw OXException.mandatoryField("userid and context required");
+    }
 }
