@@ -78,9 +78,9 @@ public class CallbackServlet extends AbstractGuardServlet {
     private static final String PUT_CONTEXTDELETED_CALLBACK_ACTION = "context_delete";
     private static final String CHECK_GUEST = "check_guest";
 
-    private final HashMap<String, GuardServletAction> putActions;
-    private final HashMap<String, GuardServletAction> getActions;
-    private final HashMap<String, GuardServletAction> postActions;
+    private transient final HashMap<String, GuardServletAction> putActions;
+    private transient final HashMap<String, GuardServletAction> getActions;
+    private transient final HashMap<String, GuardServletAction> postActions;
 
     private static final Logger logger = LoggerFactory.getLogger(CallbackServlet.class);
 
