@@ -72,7 +72,7 @@ public class ContextDeletedCallbackAction extends GuardServletAction {
 
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws OXException {
-        JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
+        JsonObject json = Services.getService(ResponseHandler.class).getJson(request);
         if (json != null) {
             RangeInputValidator<Integer> possitveValidator = new RangeInputValidator<Integer>(0, Integer.MAX_VALUE);
             int contextId = possitveValidator.assertInput(JsonUtil.getIntFromJson(json, "context_id", true /* mandatory */), "context_id");
