@@ -72,7 +72,7 @@ public class UserDeletedCallbackAction extends GuardServletAction {
 
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws OXException {
-        JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
+        JsonObject json = Services.getService(ResponseHandler.class).getJson(request);
         if (json != null) {
             RangeInputValidator<Integer> positiveValidator = new RangeInputValidator<Integer>(0, Integer.MAX_VALUE);
             int userid = positiveValidator.assertInput(JsonUtil.getIntFromJson(json, "user_id", true /* mandatory */), "user_id");
