@@ -134,15 +134,53 @@ public class FileUploadHandler {
         return configurationService.getIntProperty(GuardProperty.fileUploadBufferThreshhold);
     }
 
-    private long getConfiguredMaxUploadSize() {
+    /**
+     * Internal method to get the MAX_UPLOAD_SIZE properties from the infostore.properties file
+     *
+     * @return The configured MAX_UPLOAD_SIZE in infostore.properties which can be a value >0 in bytes, 0 (in case of unlimited) or -1 (in order to fallback to server.properties' MAX_UPLOAD_SIZE)
+     */
+    private long getInfostoreMaxUploadSize() {
         //Getting the maximum allowed upload size
-        String maxSizeProperty = configurationService.getPropertyFromFile("server.properties", "MAX_UPLOAD_SIZE");
+        String maxSizeProperty = configurationService.getPropertyFromFile("infostore.properties", "MAX_UPLOAD_SIZE");
         long maxSize = -1L;
         if (maxSizeProperty != null) {
             maxSize = Long.parseLong(maxSizeProperty);
-            if (maxSize == 0) {
-                maxSize = -1;
-            }
+        }
+        return maxSize;
+    }
+
+    /**
+     * Internal method to get the MAX_UPLOAD_SIZE properties from the server.properties file
+     *
+     * @return The configured MAX_UPLOAD_SIZE in infostore.properties which can be a value >0 in bytes or 0 (in case of unlimited)
+     */
+    private long getServerMaxUploadSize() {
+        //Getting the maximum allowed upload size
+        String maxSizeProperty = configurationService.getPropertyFromFile("server.properties", "MAX_UPLOAD_SIZE");
+        long maxSize = 0L;
+        if (maxSizeProperty != null) {
+            maxSize = Long.parseLong(maxSizeProperty);
+        }
+        return maxSize;
+    }
+
+    /**
+     * Internal method to obtain the maxium allowed size of an uploaded file.
+     * <br><br>
+     * Relies on <code>MAX_UPLOAD_SIZE</code> from <code>infostore.properties</code> and <code>server.properties</code>.
+     * @return The maximum allowed size, in bytes,  of a file upload, or -1 if unlimited
+     */
+    private long getConfiguredMaxUploadSize() {
+        //get MAX_UPLOAD_SIZE from infostore.properties
+        long maxSize = getInfostoreMaxUploadSize();
+        if (maxSize == -1) {
+            maxSize = getServerMaxUploadSize();
+            //fallback to server.properties
+        }
+
+        if (maxSize == 0) {
+            //unrestricted means "-1" in Apache's fileupload
+            maxSize = -1;
         }
         return maxSize;
     }
