@@ -93,7 +93,7 @@ public class GuestFirstPasswordAction extends GuardServletAction {
         if (antiabuse.isBad(ip)) {
             throw GuestServletExceptionCodes.LOCKOUT.create();
         }
-        JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
+        JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request, userSession.getUserId(), userSession.getContextId());
         String newpass = null;
         String question = null;
         String answer = null;
