@@ -54,6 +54,7 @@ import java.util.HashMap;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.AbstractGuardServlet;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.OXGuardSessionAuthenticationHandler;
@@ -69,12 +70,17 @@ import com.openexchange.guard.servlets.keymanagement.actions.GetKeysAction;
 import com.openexchange.guard.servlets.keymanagement.actions.GetRecipKeyAction;
 import com.openexchange.guard.servlets.keymanagement.actions.GetSignaturesAction;
 import com.openexchange.guard.servlets.keymanagement.actions.HasKeyAction;
+import com.openexchange.guard.servlets.keymanagement.actions.ImportAutocryptKeys;
+import com.openexchange.guard.servlets.keymanagement.actions.PutAutoCryptKey;
 import com.openexchange.guard.servlets.keymanagement.actions.RevokeKeyAction;
 import com.openexchange.guard.servlets.keymanagement.actions.SetCurrentKeyAction;
 import com.openexchange.guard.servlets.keymanagement.actions.SetExternalKeyInlineModeAction;
 import com.openexchange.guard.servlets.keymanagement.actions.SetExternalKeyShareModeAction;
+import com.openexchange.guard.servlets.keymanagement.actions.StartAutoCryptKeyImport;
+import com.openexchange.guard.servlets.keymanagement.actions.TransferAutoCryptKeyAction;
 import com.openexchange.guard.servlets.keymanagement.actions.UploadExternalPublicKeyAction;
 import com.openexchange.guard.servlets.keymanagement.actions.UploadKeysAction;
+import com.openexchange.guard.servlets.keymanagement.actions.VerifyAutoCryptKeyAction;
 
 /**
  * {@link KeymanagementServlet}
@@ -100,9 +106,14 @@ public class KeymanagementServlet extends AbstractGuardServlet {
     private static final String DELETE_EXTERNAL_PUBLIC = "deleteExternalPublicKey";
     private static final String SHARE_EXTERNAL_PUBLIC = "shareExternalPublicKey";
     private static final String INLINE_EXTERNAL_PUBLIC = "inlineExternalPublicKey";
+    private static final String VERIFY_AUTOCRYPT_PUBLIC = "verifyAutoCryptKey";
+    private static final String START_AUTOCRYPT_IMPORT = "startAutoCryptImport";
+    private static final String IMPORT_AUTOCRYPT_KEY = "importAutoCryptKeys";
     private static final String ADD_USER_ID = "addUserId";
     private static final String REVOKE_KEY = "revoke";
     private static final String GET_SIGNATURES = "getSignatures";
+    private static final String PUT_AUTOCRYPT = "putautocrypt";
+    private static final String POST_AUTOCRYPT_TRANSFER = "autocrypttransfer";
     private transient final HashMap<String, GuardServletAction> getActions;
     private transient final HashMap<String, GuardServletAction> postActions;
     private transient final HashMap<String, GuardServletAction> putActions;
@@ -123,6 +134,7 @@ public class KeymanagementServlet extends AbstractGuardServlet {
         getActions.put(GET_EXTERNAL_PUBLIC, new GetExternalPublicKeysAction().setAuthenticationHandler(sessionAuthenticationHandler));
         getActions.put(GET_CONTACT_KEYS, new GetContactKeysAction().setAuthenticationHandler(sessionAuthenticationHandler));
         getActions.put(GET_SIGNATURES, new GetSignaturesAction().setAuthenticationHandler(sessionAuthenticationHandler));
+        getActions.put(START_AUTOCRYPT_IMPORT, new StartAutoCryptKeyImport().setAuthenticationHandler(sessionAuthenticationHandler));
 
         //POST
         postActions = new HashMap<String, GuardServletAction>();
@@ -134,12 +146,16 @@ public class KeymanagementServlet extends AbstractGuardServlet {
         postActions.put(DELETE_KEY_ACTION, new DeleteKeyPairAction().setAuthenticationHandler(sessionAuthenticationHandler));
         postActions.put(REVOKE_KEY, new RevokeKeyAction().setAuthenticationHandler(sessionAuthenticationHandler));
         postActions.put(ADD_USER_ID, new AddUserIDAction().setAuthenticationHandler(sessionAuthenticationHandler));
+        postActions.put(IMPORT_AUTOCRYPT_KEY, new ImportAutocryptKeys().setAuthenticationHandler(sessionAuthenticationHandler));
+        postActions.put(POST_AUTOCRYPT_TRANSFER, new TransferAutoCryptKeyAction().setAuthenticationHandler(sessionAuthenticationHandler));
 
         //PUT
         putActions = new HashMap<String, GuardServletAction>();
         putActions.put(SHARE_EXTERNAL_PUBLIC, new SetExternalKeyShareModeAction().setAuthenticationHandler(sessionAuthenticationHandler));
         putActions.put(INLINE_EXTERNAL_PUBLIC, new SetExternalKeyInlineModeAction().setAuthenticationHandler(sessionAuthenticationHandler));
         putActions.put(SET_CURRENT_KEY_ACTION, new SetCurrentKeyAction().setAuthenticationHandler(sessionAuthenticationHandler));
+        putActions.put(PUT_AUTOCRYPT, new PutAutoCryptKey().setAuthenticationHandler(sessionAuthenticationHandler));
+        putActions.put(VERIFY_AUTOCRYPT_PUBLIC, new VerifyAutoCryptKeyAction().setAuthenticationHandler(sessionAuthenticationHandler));
 
         //DELETE
         deleteActions = new HashMap<String, GuardServletAction>();
