@@ -83,7 +83,7 @@ public class AddUserIDAction extends GuardServletAction {
         final long keyId = ServletUtils.getLongParameter(request, Parameters.PARAM_KEYID, mandatory);
         final String name = ServletUtils.getStringParameter(request, Parameters.PARAM_NAME, mandatory);
         final String email = new EmailValidator().assertInput(ServletUtils.getStringParameter(request, Parameters.PARAM_EMAIL, mandatory), Parameters.PARAM_EMAIL);
-        final UserIdentity userIdentity = requireUserIdentityFrom(request);
+        final UserIdentity userIdentity = requireUserIdentityFrom(request, userSession.getUserId(), userSession.getContextId());
         final String newUserId = name + " <" + email + ">";
         final GuardKeyService keyService = Services.getService(GuardKeyService.class);
         final GuardKeys keys = keyService.getKeys(userSession.getGuardUserId(), userSession.getGuardContextId(), keyId);
