@@ -49,8 +49,8 @@
 
 package com.openexchange.guard.servlets.keymanagement.actions;
 
-import static com.openexchange.guard.servlets.keymanagement.actions.Parameters.PARAM_NAME;
 import static com.openexchange.guard.servlets.keymanagement.actions.Parameters.PARAM_EMAIL;
+import static com.openexchange.guard.servlets.keymanagement.actions.Parameters.PARAM_NAME;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.exception.OXException;
@@ -61,6 +61,7 @@ import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.KeyCreationService;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
+import com.openexchange.guard.keymanagement.services.MasterKeyService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.OxCookie;
@@ -85,7 +86,7 @@ public class CreateKeyPairAction extends GuardServletAction {
         final String name = ServletUtils.getStringParameter(request, PARAM_NAME, true);
         final String secondaryEmail = ServletUtils.getStringParameter(request, PARAM_EMAIL, false);
         final String email = new EmailValidator().assertInput(new Api(new OxCookie(request.getCookies()), request).getPrimary());
-        final boolean createRecovery = keyRecoveryService.checkCreateRecovery(userSession.getGuardContextId(), userSession.getGuardUserId());
+        final boolean createRecovery = keyRecoveryService.checkCreateRecovery(userSession.getContextId(), userSession.getUserId());
         GuardKeys existingKey = keyService.getKeys(userSession.getGuardUserId(), userSession.getGuardContextId());
         final boolean isFirstKey = existingKey == null;
         final boolean markAsCurrent = true;
@@ -103,7 +104,9 @@ public class CreateKeyPairAction extends GuardServletAction {
             new String(userIdentity.getPassword()),
             userSession.getLocale(),
             markAsCurrent,
-            createRecovery);
+            createRecovery,
+            userSession.getUserId(),
+            userSession.getContextId());
 
         if (isFirstKey) {
             final boolean isUserCreatedKey = true;
@@ -112,7 +115,13 @@ public class CreateKeyPairAction extends GuardServletAction {
             keyService.addNewKey(keys);
             if(existingKey != null) {
                 keyService.updateSettingsForUser(existingKey);
-                keyService.updateAnswerQuestionForUser(existingKey);
+                keys.setQuestion(existingKey.getQuestion());
+                MasterKeyService mKeyService = Services.getService(MasterKeyService.class);
+                if (mKeyService != null) {
+                    String decrypted = mKeyService.getRcDecrypted(existingKey.getAnswer(), existingKey.getQuestion(), existingKey.getMasterKeyIndex());
+                    keys.setAnswer(mKeyService.getRcEncryted(decrypted, keys.getQuestion(), keys.getMasterKeyIndex()));
+                }
+                keyService.updateAnswerQuestionForUser(keys);
             }
         }
 
@@ -134,7 +143,7 @@ public class CreateKeyPairAction extends GuardServletAction {
             throw GuardAuthExceptionCodes.MISSING_SESSION.create();
         }
 
-        final UserIdentity userIdentity = requireUserIdentityFrom(request);
+        final UserIdentity userIdentity = requireUserIdentityFrom(request, userSession.getUserId(), userSession.getContextId());
         final GuardKeys keys = createKey(userSession, request, userIdentity);
 
         ServletUtils.sendObject(response, new GuardKeyInfoResponse(keys, new String(userIdentity.getPassword())));
