@@ -88,7 +88,7 @@ public class DownloadKeyAction extends GetKeyAction {
      * @throws Exception
      */
     private InputStream exportPrivateKey(GuardUserSession userSession, HttpServletRequest request, final GuardKeys keys)  throws Exception {
-        final UserIdentity userIdentity = requireUserIdentityFrom(request);
+        final UserIdentity userIdentity = requireUserIdentityFrom(request, userSession.getUserId(), userSession.getContextId());
         final AntiAbuseWrapper antiAbuseWrapper = getAntiAbuseWrapper(keys, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), new String(userIdentity.getPassword())));
         return antiAbuseWrapper.doAction(new AntiAbuseAction<InputStream>() {
 
@@ -110,7 +110,7 @@ public class DownloadKeyAction extends GetKeyAction {
      * @throws OXException
      */
     private InputStream exportPublicAndPrivateKey(GuardUserSession userSession, HttpServletRequest request, final GuardKeys keys) throws Exception {
-        final UserIdentity userIdentity = requireUserIdentityFrom(request);
+        final UserIdentity userIdentity = requireUserIdentityFrom(request, userSession.getUserId(), userSession.getContextId());
         final AntiAbuseWrapper antiAbuseWrapper = getAntiAbuseWrapper(keys, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), new String(userIdentity.getPassword())));
         return antiAbuseWrapper.doAction(new AntiAbuseAction<InputStream>() {
 
