@@ -155,7 +155,7 @@ public class GetRecipKeyAction extends GuardServletAction {
         }
 
         if (recipKey != null) {
-            ServletUtils.sendObject(response, new RecipKeyInfoResponse(recipKey));
+            ServletUtils.sendObject(response, new RecipKeyInfoResponse(recipKey, userSession.getUserId(), userSession.getContextId()));
         } else {
             throw GuardCoreExceptionCodes.KEY_NOT_FOUND.create();
         }
