@@ -82,7 +82,7 @@ public class RevokeKeyAction extends GuardServletAction {
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
         final boolean mandatory = true;
         final long keyId = ServletUtils.getLongParameter(request, Parameters.PARAM_KEYID, mandatory);
-        final UserIdentity userIdentity = requireUserIdentityFrom(request);
+        final UserIdentity userIdentity = requireUserIdentityFrom(request, userSession.getUserId(), userSession.getContextId());
         final String reason = ServletUtils.getStringParameter(request, Parameters.PARAM_REASON);
         final GuardKeyService keyService = Services.getService(GuardKeyService.class);
         final GuardKeys key = keyService.getKeysBySubKeyId(userSession.getGuardUserId(), userSession.getGuardContextId(), keyId);
