@@ -50,7 +50,6 @@
 package com.openexchange.guard.servlets.keymanagement.responses;
 
 import com.openexchange.guard.keymanagement.commons.RecipKey;
-import com.openexchange.guard.keymanagement.commons.trust.KeySource;
 
 /**
  * {@link RecipKeyInfoResponse}
@@ -61,14 +60,19 @@ import com.openexchange.guard.keymanagement.commons.trust.KeySource;
 public class RecipKeyInfoResponse {
 
     private final RecipKey recipKey;
+    private int userId, cid;
 
     /**
      * Initializes a new {@link RecipKeyInfoResponse}.
      *
      * @param recipKey
+     * @param userId ID of sender to adjust trust levels
+     * @param cid Context of sender
      */
-    public RecipKeyInfoResponse(RecipKey recipKey) {
+    public RecipKeyInfoResponse(RecipKey recipKey, int userId, int cid) {
         this.recipKey = recipKey;
+        this.userId = userId;
+        this.cid = cid;
     }
 
     public PublicKeyRingInfoResponse getPublicRing() {
@@ -81,8 +85,8 @@ public class RecipKeyInfoResponse {
         return recipKey.isGuest();
     }
 
-    public KeySource getKeySource() {
-        return recipKey.getKeySource();
+    public KeySourceResponse getKeySource() {
+        return new KeySourceResponse(recipKey.getKeySource(), userId, cid);
     }
 
     public boolean isNewKey() {
