@@ -69,7 +69,7 @@ public class KeyRetrievalServlet extends AbstractGuardServlet {
 
     private static final long serialVersionUID = 2005968044580975857L;
     private static final String POST_RETRIEVE_ALL_EXPOSED_KEYS_ACTION = "getExposedKeys";
-    private final HashMap<String, GuardServletAction> getActions;
+    private transient final HashMap<String, GuardServletAction> getActions;
 
     /**
      * Initializes a new {@link KeyRetrievalServlet}.
