@@ -107,28 +107,29 @@ public class EncryptAction extends GuardServletAction {
      */
     private List<String> getRecipientFromJson(JSONObject json) throws OXException, JSONException {
 
+        ArrayList<String> ret = new ArrayList<>();
         if (json.has(RECIPIENT_ARRAY_NAME)) {
             JSONArray recipients = json.getJSONArray(RECIPIENT_ARRAY_NAME);
-            ArrayList<String> ret = new ArrayList<>();
             for (int i = 0; i < recipients.length(); i++) {
                 ret.add(recipients.getString(i));
             }
-            if (json.has(SHARING_ARRAY_NAME)) {
-                JSONArray sharesArray = json.getJSONArray(SHARING_ARRAY_NAME);
-                ArrayList<String> shares = new ArrayList<>();
-                for (int i = 0; i < sharesArray.length(); i++) {
-                    if (!sharesArray.getJSONObject(i).has("email")) {
-                        throw OXException.mandatoryField("email in sharing array");
-                    }
-                    shares.add(sharesArray.getJSONObject(i).getString("email"));
+        }
+        if (json.has(SHARING_ARRAY_NAME)) {
+            JSONArray sharesArray = json.getJSONArray(SHARING_ARRAY_NAME);
+            ArrayList<String> shares = new ArrayList<>();
+            for (int i = 0; i < sharesArray.length(); i++) {
+                if (!sharesArray.getJSONObject(i).has("email")) {
+                    throw OXException.mandatoryField("email in sharing array");
                 }
-                SharingService sharingService = Services.getService(SharingService.class);
-                return sharingService.getAdditionalShareRecipients(ret, shares);
+                shares.add(sharesArray.getJSONObject(i).getString("email"));
             }
-            return ret;
-        } else {
+            SharingService sharingService = Services.getService(SharingService.class);
+            return sharingService.getAdditionalShareRecipients(ret, shares);
+        }
+        if (ret.isEmpty()) {
             throw GuardCoreExceptionCodes.JSON_PARAMETER_MISSING.create(RECIPIENT_ARRAY_NAME);
         }
+        return ret;
     }
 
     /*
@@ -168,9 +169,12 @@ public class EncryptAction extends GuardServletAction {
                 //Parsing the provided Json
                 boolean armored = JsonUtil.getBooleanFromJson(json, OPTION_ARMORED);
                 List<String> recipients = getRecipientFromJson(json);
-                UserIdentity signingIdentity = getUserIdentityFrom(json);
-                if (json.has("user") && signingIdentity == null) {
-                    throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
+                UserIdentity signingIdentity = null;
+                if (json.has("user")) {
+                    signingIdentity = getUserIdentityFrom(json);
+                    if (signingIdentity == null) {
+                        throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
+                    }
                 }
 
                 //Encrypting the data to memory or disk.
