@@ -51,11 +51,11 @@ package com.openexchange.guard.servlets.pgpmail;
 
 import java.io.IOException;
 import java.io.InputStream;
+import java.util.Collection;
 import javax.mail.MessagingException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import org.apache.commons.fileupload.FileItemIterator;
-import org.apache.commons.fileupload.FileItemStream;
+import org.apache.commons.fileupload.FileItem;
 import org.apache.commons.fileupload.FileUploadException;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -101,49 +101,26 @@ public class MimeEmailAction extends GuardServletAction {
         final String senderEmail = ServletUtils.getStringParameter(request, "email", mandatory);
         final boolean senderIsGuest =  ServletUtils.getBooleanParameter(request, "isGuest");
 
-        JSONObject json = null;
-        JSONObject guardAuthJson = null;
-        InputStream messageStream = null;
-
-        //Using streaming approach because we do not want plaintext data to be buffered on disk for parsing.
-        FileUploadHandler fileUploadHandler = new FileUploadHandler(Services.getService(GuardConfigurationService.class));
+        final boolean encryptedFileUpload = true;
+        FileUploadHandler fileUploadHandler = new FileUploadHandler(Services.getService(GuardConfigurationService.class), encryptedFileUpload);
         JsonFileUploadHandler jsonFileUploadHandler = new JsonFileUploadHandler(fileUploadHandler);
-        FileItemIterator itemIterator = fileUploadHandler.parseIterator(request);
-        while(itemIterator.hasNext()){
-        	FileItemStream fileItemStream = itemIterator.next();
-        	if(fileItemStream.getFieldName().equals(JSON_DATA_FIELD_NAME)){
-        		try(InputStream jsonStream = fileItemStream.openStream()){
-        			json = jsonFileUploadHandler.getJsonFrom(jsonStream);
-        		}
-        	}
-        	else if(fileItemStream.getFieldName().equals(JSON_AUTH_FIELD_NAME)){
-        		try(InputStream jsonStream = fileItemStream.openStream()){
-        			guardAuthJson = jsonFileUploadHandler.getJsonFrom(jsonStream);
-        		}
-        	}
-        	else if(fileItemStream.getFieldName().equals(MESSAGE_FIELD_NAME)){
-        		messageStream = fileItemStream.openStream();
-        	}
+        Collection<FileItem> items = fileUploadHandler.parseItems(request);
+        try (InputStream messageStream = fileUploadHandler.getFileItemStreamFrom(items, MESSAGE_FIELD_NAME, true)) {
 
-        	if(json != null && messageStream != null){
-        		//we got all we need: prevent that hasNext() skips the dataStream.
-        		//note: guardAuthJson might be missing if the mail should not get signed
-        		break;
-        	}
+            JSONObject json = jsonFileUploadHandler.getJsonFrom(items, JSON_DATA_FIELD_NAME, true);
+            JSONObject guardAuthJson = jsonFileUploadHandler.getJsonFrom(items, JSON_AUTH_FIELD_NAME, false);
+
+            UserIdentity signingIdentity = guardAuthJson != null ? getUserIdentityFrom(guardAuthJson) : null;
+            if (guardAuthJson != null && signingIdentity == null) {
+                throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
+            }
+
+            //Extracting user identity from the authenticationToken
+            String password = signingIdentity != null ? new String(signingIdentity.getPassword()) : null;
+
+            final GuardParsedMimeMessage parsedMimeMessage = parseMimeMessage(request, json, messageStream, userId, contextId, fromName, senderEmail, senderIsGuest);
+            MimeEncryptionService mimeEncryptor = Services.getService(MimeEncryptionService.class);
+            mimeEncryptor.doEncryption(parsedMimeMessage, userId, contextId, password, response.getOutputStream());
         }
-
-		UserIdentity signingIdentity = guardAuthJson != null
-				? getUserIdentityFrom(guardAuthJson)
-				: null;
-        if (guardAuthJson != null && signingIdentity == null) {
-            throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
-        }
-
-        //Extracting user identity from the authenticationToken
-        String password = signingIdentity != null ? new String(signingIdentity.getPassword()) : null;
-
-        final GuardParsedMimeMessage parsedMimeMessage = parseMimeMessage(request, json, messageStream, userId, contextId, fromName, senderEmail, senderIsGuest);
-        MimeEncryptionService mimeEncryptor = Services.getService(MimeEncryptionService.class);
-        mimeEncryptor.doEncryption(parsedMimeMessage, userId, contextId, password, response.getOutputStream());
     }
 }
