@@ -129,7 +129,7 @@ public class VerifyMimeEmailAction extends GuardServletAction {
         Collection<FileItem> items = fileUploadHandler.parseItems(request);
         try (InputStream messageStream = fileUploadHandler.getFileItemStreamFrom(items, MESSAGE_FIELD_NAME, true);) {
             final GuardParsedMimeMessage parsedMimeMessage = parseMimeMessage(request, messageStream, userId, contextId);
-            UserIdentity userIdentity = AuthUtils.getUserIdentityFrom(userId, contextId);
+            UserIdentity userIdentity = AuthUtils.getUserIdentityFrom(userId, contextId, userId, contextId);
 
             final MimeMessage messageToVerify = parsedMimeMessage.getMessage();
 
