@@ -84,11 +84,6 @@ public class ExposeKeyAction extends GuardServletAction {
         //Parsing parameters
         final String email = new EmailValidator().assertInput(ServletUtils.getStringParameter(request, "email", true /* mandatory */), "email");
         int cid = ServletUtils.getIntParameter(request, "cid", true /* mandatory */);
-        String language = ServletUtils.getStringParameter(request, "language", false /* optional */);
-        if (language == null) {
-            GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-            language = configService.getProperty(GuardProperty.defaultLanguage);
-        }
 
         //exposing the user's keys
         URI exposeUri = supportService.exposeKey(cid, email);
