@@ -86,7 +86,8 @@ public class ResetPasswordAction extends GuardServletAction {
         String language = ServletUtils.getStringParameter(request, "language", false /* optional */);
         if (language == null || language.isEmpty()) {
             GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-            language = configService.getProperty(GuardProperty.defaultLanguage);
+            language = configService.getProperty(GuardProperty.defaultLanguage,
+                userSession.getUserId(), userSession.getContextId());
         }
 
         //Resetting the user's password
