@@ -33,15 +33,15 @@ public class DeletedKeyExposer {
 
         GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
 
-        String base = configService.getProperty(GuardProperty.externalEmailURL);
-        final String baseDomain = configService.getProperty(GuardProperty.baseDomain);
+        String base = configService.getProperty(GuardProperty.externalEmailURL, deletedKey.getUserId(), deletedKey.getCid());
+        final String baseDomain = configService.getProperty(GuardProperty.baseDomain, deletedKey.getUserId(), deletedKey.getCid());
         if(base.isEmpty() && baseDomain.isEmpty()) {
             throw GuardCoreExceptionCodes.CONFIGURATION_ERROR.create("baseDomain", "Missing");
         }
         if (!baseDomain.isEmpty()) {
             base = baseDomain;  // BaseDomain over-rides the value of the externalEmailURL
         }
-        final String uiWebPath = configService.getProperty("com.openexchange.UIWebPath");
+        final String uiWebPath = configService.getProperty("com.openexchange.UIWebPath", deletedKey.getUserId(), deletedKey.getCid(), "MISSING");
         if(uiWebPath.isEmpty()) {
             throw GuardCoreExceptionCodes.CONFIGURATION_ERROR.create("com.openexchange.UIWebPath", "Missing");
         }
